import { Component, ViewEncapsulation, ChangeDetectionStrategy, Attribute, ChangeDetectorRef, Input, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Router, RouterModule } from '@angular/router';
import { Breakpoints, BreakpointObserver } from '@angular/cdk/layout';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import { Subject, combineLatest } from 'rxjs';
import { map, takeUntil } from 'rxjs/operators';
import { MatMenuModule } from '@angular/material/menu';
import { MatListModule } from '@angular/material/list';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';

class UxgBreadcrumbComponent {
    constructor(dense, color, router, breakpointObserver, cd) {
        this.dense = dense;
        this.color = color;
        this.router = router;
        this.breakpointObserver = breakpointObserver;
        this.cd = cd;
        this.breadcrumbs$ = new Subject();
        this._breadcrumbs = [];
        this._enableBackButton = true;
        /**
         * Back button can be displayed only in mobile mode and if breadscrumb have more than two items.
         */
        this.shouldDisplayBackButton = false;
        this.destroyed$ = new Subject();
        combineLatest([
            this.breakpointObserver.observe([Breakpoints.HandsetPortrait]).pipe(map((result) => result.matches)),
            this.breadcrumbs$
        ])
            .pipe(map(([isMobile, breadcrumbs]) => {
            return isMobile && breadcrumbs && breadcrumbs.length > 2;
        }), takeUntil(this.destroyed$))
            .subscribe((value) => {
            this.shouldDisplayBackButton = value;
            this.cd.markForCheck();
        });
    }
    get breadcrumbs() {
        if (this.shouldDisplayBackButton) {
            return this._breadcrumbs && this._breadcrumbs.length > 0 ? [this._breadcrumbs[this._breadcrumbs.length - 1]] : [];
        }
        return this._breadcrumbs;
    }
    set breadcrumbs(value) {
        this._breadcrumbs = value;
        this.breadcrumbs$.next(value);
    }
    get enableBackButton() {
        return this._enableBackButton;
    }
    set enableBackButton(value) {
        this._enableBackButton = coerceBooleanProperty(value);
    }
    ngOnDestroy() {
        this.destroyed$.next();
        this.destroyed$.complete();
    }
    backToPreviousPage() {
        if (this._breadcrumbs.length > 2) {
            const parentUrl = this._breadcrumbs[this._breadcrumbs.length - 2].url;
            if (parentUrl) {
                this.router.navigateByUrl(parentUrl);
            }
        }
    }
}
UxgBreadcrumbComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-breadcrumb',
                template: "<ul class=\"uxg-breadcrumb\" [attr.dense]=\"dense === '' ? '' : null\" [attr.color]=\"color !== '' ? color : null\">\n  <!-- back button -->\n  <ng-container *ngIf=\"shouldDisplayBackButton && enableBackButton\">\n    <li class=\"uxg-breadcrumb-back\">\n      <mat-icon class=\"uxg-breadcrumb-back\" [color]=\"color\" (click)=\"backToPreviousPage()\">chevron_left</mat-icon>\n    </li>\n  </ng-container>\n\n  <ng-container *ngFor=\"let breadcrumbItem of breadcrumbs; last as isLast\">\n    <ng-container *ngIf=\"!isLast; else lastItem\">\n      <ng-template [ngTemplateOutlet]=\"linkItem\" [ngTemplateOutletContext]=\"{ item: breadcrumbItem }\"></ng-template>\n    </ng-container>\n    <!-- Last item template -->\n    <ng-template #lastItem>\n      <!-- whether last item has items data -->\n      <ng-container *ngIf=\"breadcrumbItem.items\">\n        <li>\n          <button mat-flat-button [matMenuTriggerFor]=\"menu\" disableRipple=\"true\" [color]=\"color\">\n            <span [class]=\"breadcrumbItem.itemClass\">{{ breadcrumbItem.label }}</span>\n            <mat-icon>expand_more</mat-icon>\n          </button>\n          <mat-menu #menu=\"matMenu\" class=\"uxg-breadcrumb-menu\">\n            <mat-nav-list class=\"uxg-nav-list-level\">\n              <a\n                *ngFor=\"let item of breadcrumbItem.items\"\n                [routerLink]=\"item.url\"\n                [queryParamsHandling]=\"item.queryParamsHandling\"\n                [ngClass]=\"{ 'uxg-list-item-selected': item.label === breadcrumbItem.label }\"\n                mat-list-item\n              >\n                <mat-icon mat-list-icon>{{ item.icon ? item.icon : 'filter_none' }}</mat-icon>\n                <p>{{ item.label }}</p>\n              </a>\n            </mat-nav-list>\n          </mat-menu>\n        </li>\n      </ng-container>\n\n      <!-- display last item as  a normal linkItem -->\n      <ng-container *ngIf=\"!breadcrumbItem.items\">\n        <ng-template [ngTemplateOutlet]=\"linkItem\" [ngTemplateOutletContext]=\"{ item: breadcrumbItem }\"></ng-template>\n      </ng-container>\n    </ng-template>\n  </ng-container>\n</ul>\n\n<!-- LinkItem template -->\n<ng-template #linkItem let-breadcrumbItem=\"item\">\n  <li [class]=\"breadcrumbItem.itemClass\">\n    <ng-container *ngIf=\"breadcrumbItem.url\">\n      <a [routerLink]=\"breadcrumbItem.url\" [queryParamsHandling]=\"breadcrumbItem.queryParamsHandling\">{{\n        breadcrumbItem.label\n      }}</a>\n    </ng-container>\n    <ng-container *ngIf=\"!breadcrumbItem.url\">\n      {{ breadcrumbItem.label }}\n    </ng-container>\n  </li>\n</ng-template>\n",
                host: {
                    class: 'uxg-breadcrumb'
                },
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
/** @nocollapse */
UxgBreadcrumbComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Attribute, args: ['dense',] }] },
    { type: undefined, decorators: [{ type: Attribute, args: ['color',] }] },
    { type: Router },
    { type: BreakpointObserver },
    { type: ChangeDetectorRef }
];
UxgBreadcrumbComponent.propDecorators = {
    breadcrumbs: [{ type: Input }],
    enableBackButton: [{ type: Input }]
};

class UxgBreadcrumbModule {
}
UxgBreadcrumbModule.decorators = [
    { type: NgModule, args: [{
                imports: [RouterModule, CommonModule, MatMenuModule, MatIconModule, MatListModule, MatIconModule, MatButtonModule],
                exports: [UxgBreadcrumbComponent],
                declarations: [UxgBreadcrumbComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { UxgBreadcrumbComponent, UxgBreadcrumbModule };
//# sourceMappingURL=ffdc-uxg-angular-components-breadcrumb.js.map
