import { Component, Input, ContentChildren, EventEmitter, ViewEncapsulation, ChangeDetectionStrategy, Inject, ChangeDetectorRef, ViewChild, ContentChild, Output, NgModule } from '@angular/core';
import { DOCUMENT, CommonModule } from '@angular/common';
import { PlotComponent, PlotlyService, PlotlyViaCDNModule } from 'angular-plotly.js';
import { PaletteService, LazyloadScriptService } from '@ffdc/uxg-angular-components/core';
import { merge } from 'rxjs';

const CHART_DEFAULT_PLOTLY_LAYOUT = {
    autosize: true,
    margin: {
        l: 0,
        r: 0,
        b: 0,
        t: 0,
        pad: 0
    }
};
const CHART_DEFAULT_PLOTLY_CONFIG = {
    displaylogo: false,
    responsive: true
};
var ChartType;
(function (ChartType) {
    ChartType["bar"] = "bar";
    ChartType["stackedBar"] = "stackedBar";
    ChartType["line"] = "line";
    ChartType["scatter"] = "scatter";
    ChartType["scatterLine"] = "scatterLine";
    ChartType["stackedLine"] = "stackedLine";
    ChartType["fullStackedLine"] = "fullStackedLine";
    ChartType["spline"] = "spline";
    ChartType["stackedSpline"] = "stackedSpline";
    ChartType["fullStackedSpline"] = "fullStackedSpline";
    ChartType["stepline"] = "stepline";
    ChartType["steparea"] = "steparea";
    ChartType["area"] = "area";
    ChartType["stackedArea"] = "stackedArea";
    ChartType["fullStackedArea"] = "fullStackedArea";
    ChartType["pie"] = "pie";
    ChartType["donut"] = "donut";
})(ChartType || (ChartType = {}));
var ChartOrientation;
(function (ChartOrientation) {
    ChartOrientation["horizontal"] = "horizontal";
    ChartOrientation["vertical"] = "vertical";
})(ChartOrientation || (ChartOrientation = {}));
const CHART_PLOLTLY_TYPE = {
    [ChartType.bar]: {
        name: 'bar',
        group: 'bar',
        trace: {
            type: 'bar'
        },
        layout: {
            barmode: 'group'
        }
    },
    [ChartType.stackedBar]: {
        name: 'stackedBar',
        group: 'bar',
        trace: {
            type: 'bar'
        },
        layout: {
            barmode: 'relative'
        }
    },
    [ChartType.line]: {
        name: 'line',
        group: 'line',
        trace: {
            type: 'scatter'
        }
    },
    [ChartType.scatter]: {
        name: 'scatter',
        group: 'line',
        trace: {
            type: 'scatter',
            mode: 'markers'
        }
    },
    [ChartType.scatterLine]: {
        name: 'scatter+line',
        group: 'line',
        trace: {
            type: 'scatter',
            mode: 'lines+markers'
        }
    },
    [ChartType.stackedLine]: {
        name: 'Stacked line',
        group: 'line',
        trace: {
            type: 'scatter',
            stackgroup: 'one',
            fill: 'none'
        }
    },
    [ChartType.fullStackedLine]: {
        name: 'Full stacked line',
        group: 'line',
        trace: {
            type: 'scatter',
            stackgroup: 'one',
            groupnorm: 'percent',
            fill: 'none'
        }
    },
    [ChartType.spline]: {
        name: 'Spline',
        group: 'line',
        trace: {
            type: 'scatter',
            line: { shape: 'spline' }
        }
    },
    [ChartType.stackedSpline]: {
        name: 'Stacked spline',
        group: 'line',
        trace: {
            type: 'scatter',
            stackgroup: 'one',
            mode: 'lines+markers',
            fill: 'none',
            line: { shape: 'spline' }
        }
    },
    [ChartType.fullStackedSpline]: {
        name: 'Full stacked spline',
        group: 'line',
        trace: {
            type: 'scatter',
            stackgroup: 'one',
            groupnorm: 'percent',
            mode: 'lines+markers',
            fill: 'none',
            line: { shape: 'spline' }
        }
    },
    [ChartType.stepline]: {
        name: 'Stepline',
        group: 'line',
        trace: {
            type: 'scatter',
            line: { shape: 'hv' }
        }
    },
    [ChartType.steparea]: {
        name: 'Step area',
        group: 'line',
        trace: {
            type: 'scatter',
            stackgroup: 'one',
            line: { shape: 'hv' }
        }
    },
    [ChartType.area]: {
        name: 'Area',
        group: 'line',
        trace: {
            type: 'scatter',
            stackgroup: 'one'
        }
    },
    [ChartType.stackedArea]: {
        name: 'Stacked area',
        group: 'line',
        trace: {
            type: 'scatter',
            stackgroup: 'one'
        }
    },
    [ChartType.fullStackedArea]: {
        name: 'Full stacked area',
        group: 'line',
        trace: {
            type: 'scatter',
            stackgroup: 'one',
            groupnorm: 'percent'
        }
    },
    [ChartType.pie]: {
        name: 'pie',
        group: 'pie',
        trace: {
            type: 'pie'
        }
    },
    [ChartType.donut]: {
        name: 'donut',
        group: 'pie',
        trace: {
            type: 'pie',
            hole: 0.5,
            automargin: true,
            textposition: 'inside'
        }
    }
};

class TraceComponent {
    constructor() {
        this.type = ChartType.bar;
        this.orientation = ChartOrientation.vertical;
    }
    getPlotlyTrace() {
        const plotlyType = CHART_PLOLTLY_TYPE[this.type];
        if (plotlyType) {
            const trace = Object.assign(Object.assign(Object.assign({ dimensionName: this.dimensionName, x: this.orientation === ChartOrientation.vertical ? this.dimension : this.measure, y: this.orientation === ChartOrientation.vertical ? this.measure : this.dimension, labels: this.orientation === ChartOrientation.vertical ? this.dimension : this.measure, values: this.orientation === ChartOrientation.vertical ? this.measure : this.dimension, name: this.measureName }, (plotlyType ? plotlyType.trace : {})), { orientation: this.orientation === ChartOrientation.horizontal ? 'h' : 'v' }), (this.options ? this.options : {}));
            if (this.selectedPoints) {
                trace.selectedpoints = Array.from(this.selectedPoints);
            }
            return trace;
        }
        console.error('Chart type: ' + this.type + " doesn't exist!");
        return {};
    }
    getPlotlyTypeLayout() {
        const plotlyType = CHART_PLOLTLY_TYPE[this.type];
        return plotlyType && plotlyType.layout ? plotlyType.layout : {};
    }
}
TraceComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-trace',
                template: ''
            },] }
];
/** @nocollapse */
TraceComponent.ctorParameters = () => [];
TraceComponent.propDecorators = {
    dimension: [{ type: Input }],
    dimensionName: [{ type: Input }],
    measure: [{ type: Input }],
    measureName: [{ type: Input }],
    selectedPoints: [{ type: Input }],
    type: [{ type: Input }],
    orientation: [{ type: Input }],
    options: [{ type: Input }]
};

class GroupTracesComponent {
    getTraces() {
        return this.traces
            .map((trace) => {
            const t = trace.getPlotlyTrace();
            if (t && (this.columnPosition !== undefined || this.columnPosition !== undefined))
                t.domain = this.domain;
            return t;
        })
            .filter((trace) => !!trace);
    }
    get domain() {
        const domain = {};
        if (this.columnPosition !== undefined) {
            domain.column = this.columnPosition;
        }
        if (this.rowPosition !== undefined) {
            domain.row = this.rowPosition;
        }
        return domain;
    }
}
GroupTracesComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-group-traces',
                template: ''
            },] }
];
GroupTracesComponent.propDecorators = {
    columnPosition: [{ type: Input }],
    rowPosition: [{ type: Input }],
    traces: [{ type: ContentChildren, args: [TraceComponent,] }]
};

class LegendComponent {
    constructor() {
        this.position = LegendPosition.verticalRightTop;
    }
    getLegendPlotly() {
        return LegendPositionConvertion[this.position] ? LegendPositionConvertion[this.position] : {};
    }
}
LegendComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-legend',
                template: ''
            },] }
];
/** @nocollapse */
LegendComponent.ctorParameters = () => [];
LegendComponent.propDecorators = {
    position: [{ type: Input }]
};
var LegendPosition;
(function (LegendPosition) {
    LegendPosition["verticalLeftCenter"] = "verticalLeftCenter";
    LegendPosition["verticalLeftTop"] = "verticalLeftTop";
    LegendPosition["verticalLeftBottom"] = "verticalLeftBottom";
    LegendPosition["verticalRightCenter"] = "verticalRightCenter";
    LegendPosition["verticalRightTop"] = "verticalRightTop";
    LegendPosition["verticalRightBottom"] = "verticalRightBottom";
    LegendPosition["horizontalTopCenter"] = "horizontalTopCenter";
    LegendPosition["horizontalTopLeft"] = "horizontalTopLeft";
    LegendPosition["horizontalTopRight"] = "horizontalTopRight";
    LegendPosition["horizontalBottomCenter"] = "horizontalBottomCenter";
    LegendPosition["horizontalBottomLeft"] = "horizontalBottomLeft";
    LegendPosition["horizontalBottomRight"] = "horizontalBottomRight";
})(LegendPosition || (LegendPosition = {}));
const LegendPositionConvertion = {
    [LegendPosition.verticalLeftTop]: {
        label: 'Vertical left top',
        orientation: 'v',
        x: -0.1,
        y: 1
    },
    [LegendPosition.verticalLeftCenter]: {
        label: 'Vertical left center',
        orientation: 'v',
        x: -0.1,
        y: 0.5
    },
    [LegendPosition.verticalLeftBottom]: {
        label: 'Vertical left bottom',
        orientation: 'v',
        x: -0.1,
        y: 0
    },
    [LegendPosition.verticalRightTop]: {
        label: 'Vertical right top',
        orientation: 'v'
    },
    [LegendPosition.verticalRightCenter]: {
        label: 'Vertical right center',
        orientation: 'v',
        x: 1,
        y: 0.5
    },
    [LegendPosition.verticalRightBottom]: {
        label: 'Vertical right bottom',
        orientation: 'v',
        x: 1,
        y: 0
    },
    [LegendPosition.horizontalBottomLeft]: {
        label: 'Horizontal bottom left',
        orientation: 'h',
        x: 0,
        y: -0.1,
        xanchor: 'left'
    },
    [LegendPosition.horizontalBottomCenter]: {
        label: 'Horizontal bottom center',
        orientation: 'h',
        x: 0.5,
        y: -0.1,
        xanchor: 'center'
    },
    [LegendPosition.horizontalBottomRight]: {
        label: 'Horizontal bottom right',
        orientation: 'h',
        x: 1,
        y: -0.1,
        xanchor: 'right'
    },
    [LegendPosition.horizontalTopLeft]: {
        label: 'Horizontal top left',
        orientation: 'h',
        x: 0,
        y: 1.1,
        xanchor: 'left'
    },
    [LegendPosition.horizontalTopCenter]: {
        label: 'Horizontal top center',
        orientation: 'h',
        x: 0.5,
        y: 1.1,
        xanchor: 'center'
    },
    [LegendPosition.horizontalTopRight]: {
        label: 'Horizontal top right',
        orientation: 'h',
        x: 1.02,
        y: 1.1,
        xanchor: 'right'
    }
};

class ChartComponent {
    constructor(document, paletteService, cd, lazyLoadScriptService) {
        this.document = document;
        this.paletteService = paletteService;
        this.cd = cd;
        this.lazyLoadScriptService = lazyLoadScriptService;
        this.data = [];
        this.subscriptions = [];
        this.multiSelect = false;
        this.lastClick = {
            time: 0,
            item: { selectedItems: [], clickedItems: [] }
        };
        this.onClick = new EventEmitter();
        this.onSelected = new EventEmitter();
        this.onDoubleClick = new EventEmitter();
        this.plotlyReady$ = lazyLoadScriptService.load('plotly.js', 'Plotly');
    }
    get config() {
        return !this._config ? CHART_DEFAULT_PLOTLY_CONFIG : this._config;
    }
    set config(value) {
        this._config = this.merge_options(CHART_DEFAULT_PLOTLY_CONFIG, value);
    }
    get layout() {
        return this._layout ? this._layout : {};
    }
    set layout(value) {
        if (!this._defaultLayout)
            this.setDefautLayout();
        this._layout = this.merge_options(this.merge_options(this._defaultLayout, this._layout), value);
    }
    get revision() {
        return this.plot.revision;
    }
    set revision(value) {
        if (this.plot) {
            this.refresh();
            this.plot.revision = value;
            this.cd.markForCheck();
            this.plot.updatePlot();
        }
    }
    ngOnInit() {
        this.setDefautLayout();
        this.subscriptions.push(this.paletteService.paletteChange$.subscribe((config) => {
            this.paletteConfig = config;
        }));
    }
    ngAfterContentInit() {
        this.refresh();
        if (this.groupTraces && this.traces) {
            merge(this.groupTraces.changes, this.traces.changes).subscribe((value) => {
                this.refresh();
            });
        }
        else if (this.traces) {
            merge(this.traces.changes).subscribe((value) => {
                this.refresh();
            });
        }
        else if (this.groupTraces) {
            merge(this.groupTraces.changes).subscribe((value) => {
                this.refresh();
            });
        }
    }
    ngOnDestroy() {
        this.subscriptions.forEach((subscription) => subscription.unsubscribe());
    }
    ngOnChanges(changes) {
        this.setData();
        this.setLayout();
    }
    onSelect(event) {
        const points = event.points;
        const items = { selectedItems: new Array(), clickedItems: new Array() };
        let trace;
        points.forEach((item) => {
            var _a, _b, _c, _d, _e, _f, _g, _h;
            if (this.traces) {
                trace = this.traces.find((t) => {
                    return t.dimensionName === item.data.dimensionName && t.measureName === item.data.name;
                });
            }
            else if (this.groupTraces) {
                this.groupTraces.forEach((g) => {
                    trace = g.traces.find((t) => {
                        return t.dimensionName === item.data.dimensionName && t.measureName === item.data.name;
                    });
                });
            }
            if (trace) {
                if (item.pointIndex !== undefined) {
                    let dimension = item.data.orientation === 'v' ? item.data.x[item.pointIndex] : item.data.y[item.pointIndex];
                    let measure = item.data.orientation === 'v' ? item.data.y[item.pointIndex] : item.data.x[item.pointIndex];
                    // Get item clicked
                    items.clickedItems.push({
                        [item.data.dimensionName]: dimension,
                        [item.data.name]: measure
                    });
                    // Update selectedpoints
                    if (trace.selectedPoints && trace.selectedPoints.indexOf(item.pointIndex) !== -1) {
                        if (!this.multiSelect) {
                            // Set other trace selection to null
                            (_a = this.groupTraces) === null || _a === void 0 ? void 0 : _a.forEach((g) => {
                                var _a;
                                (_a = g.traces) === null || _a === void 0 ? void 0 : _a.forEach((t) => delete t.selectedPoints);
                            });
                            (_b = this.traces) === null || _b === void 0 ? void 0 : _b.forEach((t) => delete t.selectedPoints);
                        }
                        else {
                            let someSelected = false;
                            (_c = this.groupTraces) === null || _c === void 0 ? void 0 : _c.forEach((g) => {
                                var _a;
                                (_a = g.traces) === null || _a === void 0 ? void 0 : _a.forEach((t) => {
                                    var _a, _b;
                                    if ((t.dimensionName !== (trace === null || trace === void 0 ? void 0 : trace.dimensionName) || t.measureName !== (trace === null || trace === void 0 ? void 0 : trace.measureName)) && ((_a = t.selectedPoints) === null || _a === void 0 ? void 0 : _a.length) &&
                                        ((_b = t.selectedPoints) === null || _b === void 0 ? void 0 : _b.length) > 0)
                                        someSelected = true;
                                });
                            });
                            (_d = this.traces) === null || _d === void 0 ? void 0 : _d.forEach((t) => {
                                var _a, _b;
                                if ((t.dimensionName !== (trace === null || trace === void 0 ? void 0 : trace.dimensionName) || t.measureName !== (trace === null || trace === void 0 ? void 0 : trace.measureName)) && ((_a = t.selectedPoints) === null || _a === void 0 ? void 0 : _a.length) &&
                                    ((_b = t.selectedPoints) === null || _b === void 0 ? void 0 : _b.length) > 0)
                                    someSelected = true;
                            });
                            if (trace.selectedPoints.length === 1 && !someSelected) {
                                delete trace.selectedPoints;
                            }
                            else {
                                trace.selectedPoints.splice(trace.selectedPoints.indexOf(item.pointIndex), 1);
                            }
                            if (!someSelected) {
                                (_e = this.groupTraces) === null || _e === void 0 ? void 0 : _e.forEach((g) => {
                                    var _a;
                                    (_a = g.traces) === null || _a === void 0 ? void 0 : _a.forEach((t) => {
                                        var _a;
                                        if ((t.dimensionName !== (trace === null || trace === void 0 ? void 0 : trace.dimensionName) || t.measureName !== (trace === null || trace === void 0 ? void 0 : trace.measureName)) &&
                                            ((_a = t.selectedPoints) === null || _a === void 0 ? void 0 : _a.length) === 0)
                                            delete t.selectedPoints;
                                    });
                                });
                                (_f = this.traces) === null || _f === void 0 ? void 0 : _f.forEach((t) => {
                                    var _a;
                                    if ((t.dimensionName !== (trace === null || trace === void 0 ? void 0 : trace.dimensionName) || t.measureName !== (trace === null || trace === void 0 ? void 0 : trace.measureName)) &&
                                        ((_a = t.selectedPoints) === null || _a === void 0 ? void 0 : _a.length) === 0)
                                        delete t.selectedPoints;
                                });
                            }
                        }
                    }
                    else {
                        if (trace.selectedPoints && this.multiSelect) {
                            trace.selectedPoints.push(item.pointIndex);
                        }
                        else {
                            // Set other trace selection to empty
                            (_g = this.groupTraces) === null || _g === void 0 ? void 0 : _g.forEach((g) => {
                                var _a;
                                (_a = g.traces) === null || _a === void 0 ? void 0 : _a.forEach((t) => (t.selectedPoints = []));
                            });
                            (_h = this.traces) === null || _h === void 0 ? void 0 : _h.forEach((t) => (t.selectedPoints = []));
                            trace.selectedPoints = [item.pointIndex];
                        }
                    }
                    // Get items selected
                    if (trace.selectedPoints) {
                        trace.selectedPoints.forEach((index) => {
                            dimension = item.data.orientation === 'v' ? item.data.x[index] : item.data.y[index];
                            measure = item.data.orientation === 'v' ? item.data.y[index] : item.data.x[index];
                            items.selectedItems.push({
                                [item.data.dimensionName]: dimension,
                                [item.data.name]: measure
                            });
                        });
                    }
                }
                else if (item.pointNumber !== undefined) {
                    items.selectedItems.push({
                        [item.data.dimensionName]: item.data.labels[item.pointNumber],
                        [item.data.name]: item.data.values[item.pointNumber]
                    });
                    items.clickedItems = items.selectedItems;
                }
            }
        });
        this.onEventClick(items);
    }
    onEventClick(items) {
        const clickTime = Date.now();
        if (clickTime - this.lastClick.time < 250 &&
            this.lastClick.item &&
            this.lastClick.item.clickedItems &&
            this.lastClick.item.clickedItems.length) {
            clearTimeout(this.clickTimer);
            this.clickTimer = null;
            this.onDoubleClick.emit(this.lastClick.item.clickedItems);
        }
        else {
            this.lastClick.time = clickTime;
            this.lastClick.item = items;
            this.clickTimer = setTimeout(() => {
                this.lastClick.item = { selectedItems: [], clickedItems: [] };
                this.onClick.emit(items.selectedItems.length ? items.clickedItems : []);
                this.onSelected.emit(items.selectedItems);
                clearTimeout(this.clickTimer);
                this.revision++;
            }, 300);
        }
    }
    refresh() {
        this.setLayout();
        this.setData();
        this.cd.markForCheck();
    }
    merge_options(obj1, obj2) {
        const obj3 = {};
        if (typeof obj2 === 'undefined') {
            return obj1;
        }
        if (typeof obj1 === 'undefined') {
            return obj2;
        }
        for (const attrname in obj1) {
            if (obj1.hasOwnProperty(attrname))
                obj3[attrname] =
                    typeof obj1[attrname] === 'object' && !Array.isArray(obj1[attrname])
                        ? this.merge_options(obj1[attrname], obj2[attrname])
                        : obj1[attrname];
        }
        for (const attrname in obj2) {
            if (obj2.hasOwnProperty(attrname))
                obj3[attrname] =
                    typeof obj2[attrname] === 'object' && !Array.isArray(obj2[attrname])
                        ? this.merge_options(obj1[attrname], obj2[attrname])
                        : obj2[attrname];
        }
        return obj3;
    }
    setDefautLayout() {
        const themeContent = this.document.body;
        const tmpContent = document.createElement('chart-font');
        tmpContent.className = 'chart-font';
        tmpContent.style.display = 'none';
        themeContent.appendChild(tmpContent);
        const globalStyled = window.getComputedStyle(this.document.body.getElementsByTagName('chart-font')[0]);
        tmpContent.className = 'chart-font-legend';
        const legendStyled = window.getComputedStyle(this.document.body.getElementsByTagName('chart-font')[0]);
        tmpContent.className = 'chart-font-axis';
        const axisStyled = window.getComputedStyle(this.document.body.getElementsByTagName('chart-font')[0]);
        this._defaultLayout = {
            hovermode: 'closest',
            clickmode: 'event',
            margin: {
                t: 20,
                l: 20,
                r: 20,
                b: 20
            },
            paper_bgcolor: 'transparent',
            plot_bgcolor: 'transparent',
            legend: {
                font: {
                    family: legendStyled.fontFamily,
                    size: legendStyled.fontSize,
                    color: legendStyled.color
                }
            },
            xaxis: {
                automargin: true,
                tickfont: {
                    family: axisStyled.fontFamily,
                    size: axisStyled.fontSize,
                    color: axisStyled.color
                },
                title: {
                    font: {
                        family: axisStyled.fontFamily,
                        size: axisStyled.fontSize,
                        color: axisStyled.color
                    }
                }
            },
            yaxis: {
                automargin: true,
                tickfont: {
                    family: axisStyled.fontFamily,
                    size: axisStyled.fontSize,
                    color: axisStyled.color
                },
                title: {
                    font: {
                        family: axisStyled.fontFamily,
                        size: axisStyled.fontSize,
                        color: axisStyled.color
                    }
                }
            },
            font: {
                family: globalStyled.fontFamily,
                size: globalStyled.fontSize,
                color: globalStyled.color
            },
            bargap: parseFloat(axisStyled.margin ? axisStyled.margin.replace('px', '') : '10') / 100,
            bargroupgap: parseFloat(axisStyled.padding ? axisStyled.padding.replace('px', '') : '10') / 100
        };
        themeContent.removeChild(tmpContent);
    }
    setLayout(layout) {
        if (!this._layout)
            this._layout = this._defaultLayout;
        if (this._layout) {
            if (this.groupTraces && !this._layout.grid) {
                let row = 0, column = 0;
                this.groupTraces.forEach((grpTraces) => {
                    row = row < grpTraces.rowPosition ? grpTraces.rowPosition : row;
                    column = column < grpTraces.columnPosition ? grpTraces.columnPosition : column;
                });
                this._layout.grid = { rows: Number(row) + 1, columns: Number(column) + 1, pattern: 'independent' };
            }
            this._layout.legend = !!this.legend;
            if (this.legend) {
                this._layout.legend = Object.assign(Object.assign({}, this._layout.legend), this.legend.getLegendPlotly());
            }
            if (this.paletteConfig && this.paletteConfig.colorWay) {
                this._layout.colorway = this.paletteConfig.colorWay;
            }
        }
        if (layout) {
            this.merge_options(this._layout, layout);
        }
    }
    setData() {
        if (this.traces && this.traces.length) {
            this.data = this.traces
                .map((trace) => {
                return trace.getPlotlyTrace();
            })
                .filter((trace) => !!trace);
        }
        else if (this.groupTraces && this.groupTraces.length) {
            let datas = [];
            let nbGrp = 1;
            this.groupTraces.forEach((grpTrace) => {
                datas = [
                    ...datas,
                    ...grpTrace.getTraces().map((tr) => {
                        tr.xaxis = 'x' + nbGrp;
                        tr.yaxis = 'y' + nbGrp;
                        tr.legendgroup = 'group' + nbGrp;
                        return tr;
                    })
                ];
                nbGrp++;
            });
            this.data = datas;
        }
    }
}
ChartComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-chart',
                template: "<plotly-plot\n  *ngIf=\"plotlyReady$ | async\"\n  #plot\n  [data]=\"data\"\n  [layout]=\"layout\"\n  [config]=\"config\"\n  [useResizeHandler]=\"true\"\n  (plotly_click)=\"onSelect($event)\"\n>\n</plotly-plot>\n",
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}uxg-chart,uxg-chart .js-plotly-plot,uxg-chart plotly-plot{flex:auto;display:flex;flex-direction:column}.chart-font-axis{padding:24px;margin:48px}"]
            },] }
];
/** @nocollapse */
ChartComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] },
    { type: PaletteService },
    { type: ChangeDetectorRef },
    { type: LazyloadScriptService }
];
ChartComponent.propDecorators = {
    plot: [{ type: ViewChild, args: [PlotComponent, { static: false },] }],
    traces: [{ type: ContentChildren, args: [TraceComponent,] }],
    legend: [{ type: ContentChild, args: [LegendComponent, { static: false },] }],
    groupTraces: [{ type: ContentChildren, args: [GroupTracesComponent,] }],
    multiSelect: [{ type: Input }],
    config: [{ type: Input }],
    layout: [{ type: Input }],
    revision: [{ type: Input }],
    onClick: [{ type: Output }],
    onSelected: [{ type: Output }],
    onDoubleClick: [{ type: Output }]
};

class ChartModule {
    constructor(lazyLoadScriptService) {
        lazyLoadScriptService.load('plotly.js', 'Plotly').subscribe((plotly) => {
            PlotlyService.setPlotly(plotly);
        });
    }
}
ChartModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, PlotlyViaCDNModule],
                declarations: [ChartComponent, GroupTracesComponent, LegendComponent, TraceComponent],
                exports: [ChartComponent, GroupTracesComponent, LegendComponent, TraceComponent]
            },] }
];
/** @nocollapse */
ChartModule.ctorParameters = () => [
    { type: LazyloadScriptService }
];

/**
 * Generated bundle index. Do not edit.
 */

export { CHART_DEFAULT_PLOTLY_CONFIG, CHART_DEFAULT_PLOTLY_LAYOUT, CHART_PLOLTLY_TYPE, ChartComponent, ChartModule, ChartOrientation, ChartType, GroupTracesComponent, LegendComponent, LegendPosition, LegendPositionConvertion, TraceComponent };
//# sourceMappingURL=ffdc-uxg-angular-components-chart.js.map
