import { CommonModule } from '@angular/common';
import { EventEmitter, Component, ViewEncapsulation, ChangeDetectionStrategy, Input, Output, ViewChild, ContentChild, NgModule } from '@angular/core';
import { MatButtonModule } from '@angular/material/button';
import { MatIconModule } from '@angular/material/icon';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatTableModule } from '@angular/material/table';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { SelectionModel } from '@angular/cdk/collections';
import { MatAccordion, MatExpansionModule } from '@angular/material/expansion';
import { createChain } from '@ffdc/uxg-angular-components/core';
import cloneDeep from 'lodash/cloneDeep';
import filter from 'lodash/filter';
import find from 'lodash/find';
import groupBy from 'lodash/groupBy';
import isEqual from 'lodash/isEqual';
import map from 'lodash/map';
import omit from 'lodash/omit';
import reject from 'lodash/reject';
import { UxgTableModule } from '@ffdc/uxg-angular-components/table';

class ExpandableTableComponent {
    constructor() {
        this.startExpanded = false;
        this.rowClick = new EventEmitter();
        this.selectionChange = new EventEmitter();
        this.tableButtonsCallBack = new EventEmitter();
        this.tableHeaderCallBack = new EventEmitter();
        this.dataLength = 0;
        this.selectionModel = new SelectionModel(true, []);
        this.primaryKey = 'primaryKey';
        this.dataSource = [];
        this._dataSource = [];
        this.columns = [];
        this._columns = [];
        this.visibleColumns = [];
        this.selectable = false;
        this.rowClickable = false;
        this.groupByKey = 'id';
        this.chain = createChain({ map, groupBy, filter, find, isEqual, reject });
    }
    ngOnChanges(changes) {
        if (this.groupByKey && this.columns && this.dataSource) {
            this.selectionModel = new SelectionModel(true, []);
            this.generateColumns();
            this.generateData();
        }
    }
    generateData() {
        // add primaryKey
        let primaryKeyValue = 0;
        this.dataSource.forEach((data) => {
            data[this.primaryKey] = ++primaryKeyValue;
        });
        // input selection
        if (this.selection) {
            const initialSelection = [];
            this.selection.forEach((selectionData) => {
                this.dataSource.forEach((data) => {
                    if (isEqual(omit(data, 'primaryKey'), omit(selectionData, 'primaryKey'))) {
                        initialSelection.push(data);
                    }
                });
            });
            this.selectionModel = new SelectionModel(true, initialSelection);
        }
        this.dataLength = this.dataSource.length;
        this.dataSource = filter(this.dataSource, (data) => {
            return data[this.groupByKey];
        });
        this._dataSource = this.groupBy(this.groupByKey, this.dataSource);
    }
    generateColumns() {
        if (!this.groupByKeyLabel) {
            this.groupByKeyLabel = this.groupByKey;
        }
        this.groupInfo = find(this.columns, (c) => c.name === this.groupByKeyLabel);
        this._columns = reject(this.columns, (c) => c.name === this.groupByKeyLabel);
        this.visibleColumns = this._columns.map((c) => c.name);
    }
    groupBy(groupId, collection) {
        const dataSource = this.chain(collection)
            .groupBy(groupId)
            .map((values, id) => ({
            id,
            label: this.groupByKeyLabel ? values[0][this.groupByKeyLabel] : groupId,
            values,
            expanded: this.startExpanded
        }))
            .value();
        dataSource.forEach((ds) => {
            if (!ds.values[0][this.visibleColumns[1]]) {
                ds.values = [];
            }
        });
        return dataSource;
    }
    // All
    toggleAll() {
        if (this.selectionModel.selected.length && this.isAllSelected()) {
            this.selectionModel.selected.forEach((item) => {
                this.selectionModel.toggle(item);
            });
        }
        else {
            this._dataSource.forEach((row) => {
                row.values.forEach((item) => this.selectionModel.select(item));
            });
        }
        this.onSelectionChanged();
    }
    isAllSelected() {
        return this.selectionModel.selected.length === this.dataLength;
    }
    // Row level
    toggleRow(row) {
        const selected = this.getSelectionByRow(row);
        if (selected && selected.length === row.values.length) {
            selected.forEach((item) => {
                this.selectionModel.toggle(item);
            });
        }
        else {
            row.values.forEach((item) => this.selectionModel.select(item));
        }
        this.onSelectionChanged();
    }
    selectionHasRowValue(row) {
        return this.getSelectionByRow(row).length > 0;
    }
    isRowAllSelected(row) {
        return this.getSelectionByRow(row).length === row.values.length;
    }
    getSelectionByRow(row) {
        return filter(this.selectionModel.selected, { [this.groupByKey]: row.id });
    }
    collapseAll() {
        if (!this.accordion)
            return;
        if (this._dataSource.some((row) => row.expanded)) {
            this.accordion.closeAll();
        }
        else {
            this.accordion.openAll();
        }
    }
    getSelectedKeys(row) {
        const keys = [];
        const prediction = {};
        row.values.forEach((value, key) => {
            prediction[this.primaryKey] = value[this.primaryKey];
            if (find(this.selectionModel.selected, prediction)) {
                keys.push(key);
            }
        });
        return keys;
    }
    onTableSelectionChange(tableSelectionEvent, row) {
        const rowSelection = this.getSelectionByRow(row);
        if (tableSelectionEvent.data) {
            rowSelection.forEach((selection) => {
                this.selectionModel.toggle(selection);
            });
            tableSelectionEvent.data.forEach((selection) => {
                this.selectionModel.toggle(selection);
            });
            this.onSelectionChanged();
        }
    }
    onSelectionChanged() {
        const selectedItems = cloneDeep(this.selectionModel.selected);
        selectedItems.forEach((data) => {
            delete data[this.primaryKey];
        });
        this.selectionChange.emit(selectedItems);
    }
    onRowClicked(event) {
        if (this.rowClick) {
            this.rowClick.emit(event.data);
        }
    }
}
ExpandableTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-expandable-table',
                template: "<div class=\"expandable-table-header\">\n  <mat-checkbox\n    class=\"check-box-header\"\n    (click)=\"$event.stopPropagation()\"\n    [checked]=\"selectionModel.selected.length > 0 && isAllSelected()\"\n    [indeterminate]=\"selectionModel.selected.length > 0 && !isAllSelected()\"\n    (change)=\"$event ? toggleAll() : null\"\n    *ngIf=\"selectable\"\n    color=\"primary\"\n  >\n  </mat-checkbox>\n  <div class=\"title uxg-subtitle-1\" [ngClass]=\"{ selectable: selectable }\">\n    {{ groupInfo?.displayName || groupInfo?.name }}\n  </div>\n\n  <div class=\"up-down\">\n    <button mat-icon-button (click)=\"collapseAll(); $event.stopPropagation()\" [disableRipple]=\"true\">\n      <mat-icon>code</mat-icon>\n    </button>\n  </div>\n</div>\n\n<mat-accordion *ngIf=\"_dataSource && _dataSource.length > 0\" multi=\"true\">\n  <mat-expansion-panel\n    *ngFor=\"let row of _dataSource\"\n    [expanded]=\"row.expanded\"\n    (opened)=\"row.expanded = true\"\n    (closed)=\"row.expanded = false\"\n  >\n    <mat-expansion-panel-header>\n      <mat-panel-title>\n        <mat-checkbox\n          class=\"check-box-header\"\n          (click)=\"$event.stopPropagation()\"\n          [checked]=\"selectionHasRowValue(row) && isRowAllSelected(row)\"\n          [indeterminate]=\"selectionHasRowValue(row) && !isRowAllSelected(row)\"\n          (change)=\"$event ? toggleRow(row) : null\"\n          *ngIf=\"selectable\"\n          color=\"primary\"\n        >\n        </mat-checkbox>\n        <div class=\"header-text\" [ngClass]=\"{ selectable: selectable }\">\n          <span class=\"title uxg-subtitle-1\">{{ row.label }}</span>\n          <span class=\"subtitle uxg-body-3\">\n            <ng-container *ngTemplateOutlet=\"templateHeaderSubtitle; context: { row: row, subtitle: subtitle }\">\n            </ng-container>\n          </span>\n        </div>\n        <div class=\"header-buttons\">\n          <ng-container\n            *ngTemplateOutlet=\"templateHeaderButtons; context: { row: row, emiter: tableHeaderCallBack }\"\n          ></ng-container>\n        </div>\n      </mat-panel-title>\n    </mat-expansion-panel-header>\n    <uxg-table\n      id=\"{{ row.id }}\"\n      class=\"sub-table\"\n      [data]=\"row.values\"\n      [columns]=\"_columns\"\n      [columnsToDisplay]=\"visibleColumns\"\n      (selectChanged)=\"onTableSelectionChange($event, row)\"\n      [multiSelect]=\"selectable\"\n      [singleSelect]=\"!selectable\"\n      [selectedKeys]=\"getSelectedKeys(row)\"\n      (multiSelectSingleRowClicked)=\"onRowClicked($event)\"\n      *ngIf=\"row && row.values && _columns\"\n    >\n    </uxg-table>\n    <div class=\"table-buttons\">\n      <ng-container *ngTemplateOutlet=\"templateTableButtons; context: { row: row, emiter: tableButtonsCallBack }\">\n      </ng-container>\n    </div>\n  </mat-expansion-panel>\n</mat-accordion>\n",
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush,
                animations: [
                    trigger('detailExpand', [
                        state('collapsed', style({ height: '0px', minHeight: '0', padding: '0' })),
                        state('expanded', style({ height: '*' })),
                        transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)'))
                    ])
                ],
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}uxg-expandable-table{width:100%;border-collapse:collapse}uxg-expandable-table .expandable-table-header{display:flex;align-items:center;padding:8px 8px 8px 24px}uxg-expandable-table .expandable-table-header .title.selectable{padding-left:16px}uxg-expandable-table .expandable-table-header .up-down{transform:rotate(90deg);margin-left:auto}uxg-expandable-table .check-box-header{margin-right:16px;display:flex}uxg-expandable-table .mat-expansion-panel{border-radius:0!important}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-header{padding-left:0}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-header .mat-expansion-panel-header-title{margin-right:0;align-items:center;padding-left:24px;min-height:48px}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-header .mat-expansion-panel-header-title .header-text{display:flex;flex-direction:column}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-header .mat-expansion-panel-header-title .header-text.selectable{padding-left:16px}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-header .mat-expansion-panel-header-title .header-text .subtitle{opacity:.8}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-header .mat-expansion-panel-header-title .header-buttons{margin-left:auto}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-header .mat-expansion-indicator{display:flex}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-body{padding:0}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-body .mat-table{table-layout:fixed}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-body .mat-table .mat-header-cell .mat-checkbox{display:none}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-body .mat-table tr.clickable{cursor:pointer}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-body .mat-table.sub-table{width:100%}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-body .mat-table.not-selectable td.mat-cell:first-of-type,uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-body .mat-table.not-selectable th.mat-header-cell:first-of-type{padding-left:32px!important}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-body .mat-table td.mat-cell:first-of-type,uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-body .mat-table th.mat-header-cell:first-of-type{padding-left:24px!important}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-body .mat-table .mat-column-uxg-table-select-row{width:16px}uxg-expandable-table .mat-expansion-panel .mat-expansion-panel-body .mat-table .mat-column-uxg-table-select-row .check-box{display:flex}"]
            },] }
];
/** @nocollapse */
ExpandableTableComponent.ctorParameters = () => [];
ExpandableTableComponent.propDecorators = {
    dataSource: [{ type: Input }],
    columns: [{ type: Input }],
    groupByKey: [{ type: Input }],
    groupByKeyLabel: [{ type: Input }],
    subtitle: [{ type: Input }],
    selectable: [{ type: Input }],
    rowClickable: [{ type: Input }],
    selection: [{ type: Input }],
    startExpanded: [{ type: Input }],
    rowClick: [{ type: Output }],
    selectionChange: [{ type: Output }],
    tableButtonsCallBack: [{ type: Output }],
    tableHeaderCallBack: [{ type: Output }],
    accordion: [{ type: ViewChild, args: [MatAccordion, { static: false },] }],
    templateHeaderButtons: [{ type: ContentChild, args: ['expandableHeaderButtonsTemplate', { static: false },] }],
    templateTableButtons: [{ type: ContentChild, args: ['expandableTableButtonsTemplate', { static: false },] }],
    templateHeaderSubtitle: [{ type: ContentChild, args: ['expandableTableSubtitleTemplate', { static: false },] }]
};

class ExpandableTableModule {
}
ExpandableTableModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ExpandableTableComponent],
                imports: [
                    CommonModule,
                    MatTableModule,
                    MatIconModule,
                    MatButtonModule,
                    MatExpansionModule,
                    MatCheckboxModule,
                    UxgTableModule
                ],
                exports: [ExpandableTableComponent],
                entryComponents: [ExpandableTableComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { ExpandableTableComponent, ExpandableTableModule };
//# sourceMappingURL=ffdc-uxg-angular-components-expandable-table.js.map
