import { EventEmitter, SimpleChange, Component, ElementRef, Input, Output, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { SelectionModel } from '@angular/cdk/collections';
import { NestedTreeControl } from '@angular/cdk/tree';
import { MatTreeNestedDataSource, MatTreeModule } from '@angular/material/tree';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatChipsModule } from '@angular/material/chips';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';

class FilterTreeComponent {
    constructor(hostElement) {
        this.hostElement = hostElement;
        this.treeControl = new NestedTreeControl((node) => node.children);
        this.dataSource = new MatTreeNestedDataSource();
        this.selectedData = [];
        this._data = [];
        this.multipleSelection = true;
        this.changes = new EventEmitter();
        this.hasChild = (_, node) => node.children && node.children.length;
        this.hostElement.nativeElement.__component = this;
    }
    set data(data) {
        this._data = data;
    }
    get data() {
        return this._data;
    }
    ngOnChanges(changes) {
        if (changes.data || changes.selectedData) {
            changes.data ? (this.dataSource.data = changes.data.currentValue) : (this.dataSource.data = this.data);
            changes.selectedData
                ? (this.selectedData = changes.selectedData.currentValue)
                : (this.selectedData = this.getSelectedNodes(this.dataSource.data));
            this.checkListSelection = new SelectionModel(this.multipleSelection, this.selectedData);
            if (this.subscription) {
                this.subscription.unsubscribe();
            }
            // tslint:disable-next-line: no-shadowed-variable
            this.subscription = this.checkListSelection.changed.subscribe((changes) => {
                this.changes.emit({
                    added: changes.added,
                    removed: changes.removed
                });
            });
        }
    }
    clearSelection() {
        this.checkListSelection.clear();
    }
    toggleAllNodes() {
        this.treeControl.collapseAll();
    }
    descendantsAllSelected(node) {
        const descendants = this.treeControl.getDescendants(node);
        const descAllSelected = descendants.every((child) => this.checkListSelection.isSelected(child));
        return descAllSelected;
    }
    descendantsPartiallySelected(node) {
        const descendants = this.treeControl.getDescendants(node);
        const result = descendants.some((child) => this.checkListSelection.isSelected(child));
        return result && !this.descendantsAllSelected(node);
    }
    itemSelectionToggle(node) {
        this.checkListSelection.toggle(node);
        const descendants = this.treeControl.getDescendants(node);
        this.checkListSelection.isSelected(node)
            ? this.checkListSelection.select(...descendants)
            : this.checkListSelection.deselect(...descendants);
        descendants.every((child) => this.checkListSelection.isSelected(child));
        this.checkAllParentsSelection(node);
    }
    leafItemSelectionToggle(node) {
        this.checkListSelection.toggle(node);
        this.checkAllParentsSelection(node);
    }
    checkAllParentsSelection(node) {
        let parent = this.getParentNode(node);
        while (parent) {
            this.checkRootNodeSelection(parent);
            parent = this.getParentNode(parent);
        }
    }
    checkRootNodeSelection(node) {
        const nodeSelected = this.checkListSelection.isSelected(node);
        const descendants = this.treeControl.getDescendants(node);
        const descAllSelected = descendants.every((child) => this.checkListSelection.isSelected(child));
        if (nodeSelected && !descAllSelected) {
            this.checkListSelection.deselect(node);
        }
        else if (!nodeSelected && descAllSelected) {
            this.checkListSelection.select(node);
        }
    }
    getParentNode(currentNode) {
        let parentNode = null;
        this.dataSource.data.forEach((node) => {
            if (node.children && node.children.length > 0) {
                node.children.forEach((child) => {
                    if (currentNode.label === child.label) {
                        parentNode = node;
                    }
                });
            }
        });
        return parentNode;
    }
    getRootNode(currentNode) {
        const parentNode = this.getParentNode(currentNode);
        if (parentNode) {
            return this.getRootNode(parentNode);
        }
        return currentNode;
    }
    isRootNodeSelected(node) {
        return this.checkListSelection.isSelected(this.getRootNode(node));
    }
    expandStart(node, el) {
        if (this.treeControl.isExpanded(node)) {
            el.classList.remove('collapsed');
        }
    }
    expandEnd(node, el) {
        if (!this.treeControl.isExpanded(node)) {
            el.classList.add('collapsed');
        }
    }
    getSelectedNodes(data) {
        const result = data.reduce((acc, node) => {
            if (node.isSelected)
                acc.push(node);
            if (node.children) {
                const childNodes = node.children.filter((childNode) => childNode.isSelected);
                acc.push(...childNodes);
            }
            return acc;
        }, new Array());
        return result;
    }
    getState() {
        return [...this.checkListSelection.selected];
    }
    setState(data) {
        this.ngOnChanges({ selectedData: new SimpleChange(null, [...data], false) });
    }
}
FilterTreeComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-filter-tree',
                template: "<mat-tree [dataSource]=\"dataSource\" [treeControl]=\"treeControl\" class=\"filter-tree\">\n  <mat-tree-node *matTreeNodeDef=\"let node\" matTreeNodeToggle>\n    <mat-checkbox\n      class=\"checklist-leaf-node\"\n      [checked]=\"checkListSelection.isSelected(node)\"\n      (change)=\"leafItemSelectionToggle(node)\"\n      color=\"primary\"\n    >\n      <span class=\"mat-tree-node uxg-body-2 node-label\">{{ node.label }}</span>\n    </mat-checkbox>\n  </mat-tree-node>\n  <mat-nested-tree-node *matTreeNodeDef=\"let node; when: hasChild\">\n    <div class=\"mat-tree-node\">\n      <mat-checkbox\n        [checked]=\"descendantsAllSelected(node)\"\n        [indeterminate]=\"descendantsPartiallySelected(node)\"\n        (change)=\"itemSelectionToggle(node)\"\n        color=\"primary\"\n      >\n        <span class=\"uxg-body-2 node-label\">{{ node.label }}</span>\n      </mat-checkbox>\n      <button mat-button mat-icon-button matTreeNodeToggle [attr.aria-label]=\"'toggle ' + node.label\" dense>\n        <mat-icon class=\"mat-icon-rtl-mirror\">\n          {{ treeControl.isExpanded(node) ? 'expand_less' : 'expand_more' }}\n        </mat-icon>\n      </button>\n    </div>\n    <div\n      class=\"child-tree\"\n      #el\n      [@slideInOut]=\"treeControl.isExpanded(node) ? 'in' : 'out'\"\n      (@slideInOut.start)=\"expandStart(node, el)\"\n      (@slideInOut.done)=\"expandEnd(node, el)\"\n    >\n      <ng-container matTreeNodeOutlet></ng-container>\n    </div>\n  </mat-nested-tree-node>\n</mat-tree>\n",
                animations: [
                    trigger('slideInOut', [
                        state('in', style({
                            overflow: 'hidden',
                            height: '*'
                        })),
                        state('out', style({
                            opacity: '0',
                            overflow: 'hidden',
                            height: '0'
                        })),
                        transition('in => out', animate('250ms ease-out')),
                        transition('out => in', animate('250ms ease-in'))
                    ])
                ],
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}.filter-tree,.filter-tree .child-tree{margin-top:0;margin-bottom:0;list-style-type:none}.filter-tree .child-tree{padding:4px 24px}.filter-tree .child-tree.collapsed{padding-top:0;padding-bottom:0;visibility:hidden}.mat-tree-node{justify-content:space-between;min-height:32px;overflow:visible}"]
            },] }
];
/** @nocollapse */
FilterTreeComponent.ctorParameters = () => [
    { type: ElementRef }
];
FilterTreeComponent.propDecorators = {
    data: [{ type: Input }],
    multipleSelection: [{ type: Input }],
    changes: [{ type: Output }]
};

class FilterTreeModule {
}
FilterTreeModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    ReactiveFormsModule,
                    MatCheckboxModule,
                    MatChipsModule,
                    MatIconModule,
                    MatButtonModule,
                    MatTreeModule
                ],
                declarations: [FilterTreeComponent],
                exports: [FilterTreeComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { FilterTreeComponent, FilterTreeModule };
//# sourceMappingURL=ffdc-uxg-angular-components-filter-filter-tree.js.map
