import { EventEmitter, Component, ViewEncapsulation, ViewChild, Input, Output, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { MatTable, MatTableModule } from '@angular/material/table';
import { MatPaginatorModule } from '@angular/material/paginator';
import { MatSortModule } from '@angular/material/sort';
import { MatIconModule } from '@angular/material/icon';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { MatButtonModule } from '@angular/material/button';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatInputModule } from '@angular/material/input';
import { CdkTableModule } from '@angular/cdk/table';
import { moveItemInArray, DragDropModule } from '@angular/cdk/drag-drop';
import isEqual from 'lodash/isEqual';
import { FormsModule } from '@angular/forms';

var UxgColumnType;
(function (UxgColumnType) {
    UxgColumnType["string"] = "string";
    UxgColumnType["number"] = "number";
    UxgColumnType["date"] = "date";
    UxgColumnType["typedouble"] = "typedouble";
    UxgColumnType["cellTemplate"] = "cellTemplate";
})(UxgColumnType || (UxgColumnType = {}));
var UxgActionColumnPosition;
(function (UxgActionColumnPosition) {
    UxgActionColumnPosition["start"] = "start";
    UxgActionColumnPosition["end"] = "end";
})(UxgActionColumnPosition || (UxgActionColumnPosition = {}));
const UxgDefaultPaging = {
    disabled: false,
    pageIndex: 0,
    length: 0,
    hidePageSize: false,
    pageSizeOptions: [5, 10],
    pageSize: 5,
    showFirstLastButtons: true
};

class TableComponent {
    constructor() {
        this.columns = []; // columns definitions
        this.showTotalRows = false;
        this.showTableHeader = true;
        this.totalData = null;
        // table config
        this.stickyHeader = true;
        this.stickyFooter = false;
        this.columnDragEnable = false;
        this.uxgMultiSelectColumn = ['uxg-table-select-row'];
        this._selectedIndex = [];
        this.singleSelect = false;
        this.multiSelect = false;
        this.selectChanged = new EventEmitter();
        this.multiSelectSingleRowClicked = new EventEmitter();
        this.sortChanged = new EventEmitter();
        //paginator data
        this.pageEnable = false;
        this.pageChanged = new EventEmitter();
        this.enableEdit = false;
        this.enableDelete = false;
        this.enableSend = false;
        this.actionColumnPosition = UxgActionColumnPosition.end;
        this.rowRemoved = new EventEmitter();
        this.rowUpdated = new EventEmitter();
        this.rowSend = new EventEmitter();
        this.selections = [];
        this.dataToComponent = [];
        this.columnsToDisplayToComponent = [];
        //local variable
        this.previousIndex = -1; // used for column drag drop
        //table data
        this._data = [];
        this._columnsToDisplay = [];
        this.uxgTableEdit = false;
        //edit part
        this.uxgTableActionColumn = ['uxg-table-action-row'];
    }
    get data() {
        return this._data;
    }
    set data(data) {
        this._data = data;
        this.dataToComponent = data;
    }
    get columnsToDisplay() {
        return this._columnsToDisplay;
    }
    set columnsToDisplay(columnsToDisplay) {
        this._columnsToDisplay = columnsToDisplay;
        this.columnsToDisplayToComponent = columnsToDisplay;
        if (this.multiSelect && this.columnsToDisplayToComponent.indexOf(this.uxgMultiSelectColumn[0]) < 0) {
            this.columnsToDisplayToComponent = this.uxgMultiSelectColumn.concat(this.columnsToDisplayToComponent);
        }
        if ((this.enableEdit || this.enableDelete) &&
            this.columnsToDisplayToComponent.indexOf(this.uxgTableActionColumn[0]) < 0) {
            this.addOrUpdateActionColumnToColumnsToDisplay();
        }
    }
    get selectedKeys() {
        return this._selectedIndex;
    }
    set selectedKeys(selectedIndex) {
        this._selectedIndex = selectedIndex;
        if (this.singleSelect && selectedIndex && selectedIndex.length > 0) {
            if (this.isRowSelected(this.data[selectedIndex[0]])) {
                this.selections.push(this.data[selectedIndex[0]]);
            }
        }
        if (!this.singleSelect && this.multiSelect) {
            this.selections.length = 0;
            selectedIndex.forEach((sIndex) => {
                if (!this.isRowSelected(this.data[sIndex])) {
                    this.selections.push(this.data[sIndex]);
                }
            });
        }
    }
    ngOnInit() {
        if (this.singleSelect && this.multiSelect) {
            this.multiSelect = false;
        }
        if (this.multiSelect && this.columnsToDisplayToComponent.indexOf(this.uxgMultiSelectColumn[0]) < 0) {
            this.columnsToDisplayToComponent = this.uxgMultiSelectColumn.concat(this.columnsToDisplay);
        }
        if ((this.enableEdit || this.enableDelete) &&
            this.columnsToDisplayToComponent.indexOf(this.uxgTableActionColumn[0]) < 0) {
            this.addOrUpdateActionColumnToColumnsToDisplay();
        }
        if (this.pageEnable && !this.paging) {
            this.applyDefaultPaging();
        }
    }
    ngOnChanges(changes) {
        if (changes.data && !changes.data.isFirstChange()) {
            this.table.renderRows();
            if (this.pageEnable && !this.paging) {
                this.applyDefaultPaging();
            }
        }
        if (changes.pageEnable && !changes.pageEnable.isFirstChange()) {
            if (changes.pageEnable.currentValue === false) {
                this.dataToComponent = this.data;
                this.paging = undefined;
            }
            else {
                if (!this.paging) {
                    this.applyDefaultPaging();
                }
            }
        }
        if (changes.paging && !changes.paging.isFirstChange()) {
            if (changes.paging.currentValue === null) {
                this.applyDefaultPaging();
            }
        }
        if (changes.multiSelect && !changes.multiSelect.isFirstChange()) {
            this.columnsToDisplayToComponent = this.columnsToDisplay;
            if (this.multiSelect) {
                this.columnsToDisplayToComponent = this.uxgMultiSelectColumn.concat(this.columnsToDisplay);
            }
            this.emitSelectEvent();
        }
        if (changes.singleSelect && !changes.singleSelect.isFirstChange()) {
            if (this.singleSelect) {
                this.columnsToDisplayToComponent = this.columnsToDisplay;
                if (this.selections.length > 1)
                    this.selections.splice(1, this.selections.length);
            }
            this.emitSelectEvent();
        }
        if (changes.enableEdit && !changes.enableEdit.isFirstChange()) {
            this.resetActionRow();
        }
        if (changes.enableDelete && !changes.enableDelete.isFirstChange()) {
            this.resetActionRow();
        }
        if (changes.enableSend && !changes.enableSend.isFirstChange()) {
            this.resetActionRow();
        }
        if (changes.actionColumnPosition && !changes.actionColumnPosition.isFirstChange()) {
            this.addOrUpdateActionColumnToColumnsToDisplay();
        }
    }
    sortData($event) {
        if (this.sortChanged.observers.length > 0) {
            this.sortChanged.emit($event);
        }
        else {
            this.dataToComponent = this.localSort($event);
        }
    }
    singleSelectRowClick(row) {
        if (this.uxgTableEdit)
            return;
        this.dataToComponent.forEach((item) => delete item.uxgTableEdit);
        if (this.singleSelect) {
            if (!this.isRowSelected(row)) {
                this.selections = [row];
            }
            else {
                this.selections = [];
            }
            this.emitSelectEvent();
            return;
        }
        if (!this.singleSelect && this.multiSelect) {
            this.emitClickEvent(row);
            return;
        }
    }
    multiSelectRowClick(row) {
        if (this.uxgTableEdit)
            return;
        if (!this.multiSelect) {
            return;
        }
        if (!this.isRowSelected(row)) {
            this.selections.push(row);
        }
        else {
            this.selections.splice(this.getSelectedIndex(row), 1);
        }
        this.emitSelectEvent();
    }
    multiSelectAllRows($event) {
        if ($event.checked) {
            this.selections = this.dataToComponent;
        }
        else {
            this.selections = [];
        }
        this.emitSelectEvent();
    }
    applyPageChanges($event) {
        if (this.pageChanged.observers.length > 0) {
            this.pageChanged.emit($event);
        }
        else {
            this.localPaging($event);
        }
    }
    getTotalRowCell(column) {
        if (this.totalData && this.totalData[column.name]) {
            return this.totalData[column.name];
        }
        else {
            if (column.type === UxgColumnType.number) {
                return this.dataToComponent.reduce((sum, current) => sum + current[column.name], 0);
            }
            else {
                return '';
            }
        }
    }
    emitSelectEvent() {
        this.selectChanged.emit({
            singleSelect: this.singleSelect ? true : false,
            data: this.selections
        });
    }
    emitClickEvent(data) {
        this.multiSelectSingleRowClicked.emit({
            data: data
        });
    }
    columnDragStarted($event, index) {
        index = this.resetIndexWithMultiSelectRow(index);
        this.previousIndex = index;
    }
    columnDropped($event, index) {
        index = this.resetIndexWithMultiSelectRow(index);
        if ($event) {
            moveItemInArray(this.columnsToDisplayToComponent, this.previousIndex, index);
        }
    }
    rowEditClick(row) {
        this.dataToComponent.forEach((item) => {
            delete item.uxgTableEdit;
        });
        this.editRowOrigin = Object.assign({}, row);
        row.uxgTableEdit = true;
        this.uxgTableEdit = true;
    }
    rowSendTriggered(row) {
        this.rowSend.emit({
            data: row
        });
    }
    rowEditConfirm(newRow) {
        delete newRow.uxgTableEdit;
        this.uxgTableEdit = false;
        this.rowUpdated.emit({
            data: newRow
        });
    }
    rowEditCancel(row) {
        delete row.uxgTableEdit;
        this.uxgTableEdit = false;
        Object.keys(row).forEach((key) => {
            row[key] = this.editRowOrigin[key];
        });
    }
    rowDelete(row) {
        const rowIndex = this.dataToComponent.findIndex((item) => item === row);
        this.dataToComponent.splice(rowIndex, 1);
        this.dataToComponent = this.dataToComponent.slice();
        this.rowRemoved.emit({
            data: row
        });
    }
    ngOnDestroy() { }
    //local functions
    applyDefaultPaging() {
        const defaultPaging = Object.assign(Object.assign({}, UxgDefaultPaging), { length: this.dataToComponent.length });
        this.paging = defaultPaging;
        this.localPaging({
            pageIndex: this.paging.pageIndex || 0,
            pageSize: this.paging.pageSize || 5,
            length: this.data.length
        });
    }
    localSort(sort) {
        return this.dataToComponent.slice().sort((a, b) => {
            let comparison = 0;
            switch (this.getSortColumnType(sort.active)) {
                case 'number':
                    comparison = a[sort.active] - b[sort.active];
                    break;
                default:
                    if (a[sort.active].toUpperCase() > b[sort.active].toUpperCase()) {
                        comparison = 1;
                    }
                    else {
                        comparison = -1;
                    }
            }
            if (sort.direction === 'asc') {
                return comparison;
            }
            else {
                return -comparison;
            }
        });
    }
    getSortColumnType(columnName) {
        const column = this.columns.find((item) => {
            return item.name === columnName;
        });
        return column ? column.type : undefined;
    }
    localPaging(page) {
        const offset = page.pageIndex * page.pageSize;
        this.dataToComponent = this.data.slice(offset, offset + page.pageSize);
    }
    resetIndexWithMultiSelectRow(index) {
        return this.multiSelect ? index + 1 : index;
    }
    resetActionRow() {
        if ((this.enableDelete || this.enableEdit || this.enableSend) &&
            this.columnsToDisplayToComponent.indexOf(this.uxgTableActionColumn[0]) < 0) {
            this.addOrUpdateActionColumnToColumnsToDisplay();
        }
        if (!this.enableSend &&
            !this.enableDelete &&
            !this.enableEdit &&
            this.columnsToDisplayToComponent.indexOf(this.uxgTableActionColumn[0]) > -1) {
            this.removeActionColumnsFromColumnsToDisplay();
        }
    }
    isRowSelected(row) {
        return this.getSelectedIndex(row) > -1 ? true : false;
    }
    getSelectedIndex(row) {
        const rowIdx = this.selections.findIndex((item) => {
            return isEqual(item, row);
        });
        return rowIdx > -1 ? rowIdx : -1;
    }
    addOrUpdateActionColumnToColumnsToDisplay() {
        if (this.columnsToDisplayToComponent.indexOf(this.uxgTableActionColumn[0]) > -1) {
            this.removeActionColumnsFromColumnsToDisplay();
        }
        if (!this.actionColumnPosition || this.actionColumnPosition === UxgActionColumnPosition.end) {
            this.columnsToDisplayToComponent = this.columnsToDisplayToComponent.concat(this.uxgTableActionColumn);
        }
        if (this.actionColumnPosition === UxgActionColumnPosition.start) {
            this.columnsToDisplayToComponent = this.uxgTableActionColumn.concat(this.columnsToDisplayToComponent);
        }
    }
    removeActionColumnsFromColumnsToDisplay() {
        if (this.columnsToDisplayToComponent.indexOf(this.uxgTableActionColumn[0]) > -1)
            this.columnsToDisplayToComponent.splice(this.columnsToDisplayToComponent.indexOf(this.uxgTableActionColumn[0]), 1);
    }
}
TableComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-table',
                template: "<div class=\"uxg-data-table\">\n  <table\n    mat-table\n    matSort\n    cdkDropListGroup\n    [dataSource]=\"dataToComponent\"\n    (matSortChange)=\"sortData($event)\"\n    class=\"mat-elevation-z8 main-data-table\"\n  >\n    <ng-container matColumnDef=\"uxg-table-select-row\" *ngIf=\"multiSelect\">\n      <th mat-header-cell *matHeaderCellDef>\n        <mat-checkbox\n          (change)=\"multiSelectAllRows($event)\"\n          [checked]=\"selections.length !== 0 && selections.length === this.dataToComponent.length\"\n          [indeterminate]=\"selections.length !== 0 && selections.length !== this.dataToComponent.length\"\n          color=\"primary\"\n        >\n        </mat-checkbox>\n      </th>\n      <td mat-cell *matCellDef=\"let row\">\n        <mat-checkbox\n          (click)=\"$event.stopPropagation()\"\n          (change)=\"multiSelectRowClick(row)\"\n          [checked]=\"isRowSelected(row)\"\n          color=\"primary\"\n        >\n        </mat-checkbox>\n      </td>\n      <td mat-footer-cell *matFooterCellDef></td>\n    </ng-container>\n    <ng-container matColumnDef=\"{{ column.name }}\" *ngFor=\"let column of columns; let columnIndex = index\">\n      <th\n        mat-header-cell\n        *matHeaderCellDef\n        mat-sort-header\n        cdkDropList\n        cdkDropListLockAxis=\"x\"\n        cdkDropListOrientation=\"horizontal\"\n        (cdkDropListDropped)=\"columnDropped($event, columnIndex)\"\n        cdkDrag\n        (cdkDragStarted)=\"columnDragStarted($event, columnIndex)\"\n        [cdkDragDisabled]=\"!columnDragEnable\"\n        [ngClass]=\"{\n          left: column.align === 'left',\n          center: column.align === 'center',\n          right: column.align === 'right'\n        }\"\n      >\n        {{ column.displayName ? column.displayName : column.name }}\n      </th>\n      <td\n        mat-cell\n        *matCellDef=\"let element\"\n        [ngClass]=\"{\n          left: column.align === 'left',\n          center: column.align === 'center',\n          right: column.align === 'right'\n        }\"\n      >\n        <!-- view cell, display data cell according to the type -->\n        <div\n          [ngSwitch]=\"column.type\"\n          class=\"uxg-table-row-view\"\n          [ngClass]=\"{ 'uxg-cell-hidden': element.uxgTableEdit }\"\n        >\n          <div *ngSwitchCase=\"'date'\">\n            <mat-icon>date_range</mat-icon>\n            {{ element[column.name] }}\n          </div>\n          <div *ngSwitchCase=\"'cellTemplate'\">\n            <ng-template\n              [ngTemplateOutletContext]=\"{\n                element: element,\n                column: column,\n                emiter: column.cellTemplateEmiter\n              }\"\n              [ngTemplateOutlet]=\"column.cellTemplate\"\n            >\n            </ng-template>\n          </div>\n          <div *ngSwitchDefault>{{ element[column.name] }}</div>\n        </div>\n        <!-- edit cell -->\n        <div class=\"uxg-table-row-edit\" [ngClass]=\"{ 'uxg-cell-hidden': !element.uxgTableEdit }\">\n          <div [ngSwitch]=\"column.type\">\n            <div *ngSwitchCase=\"'cellTemplate'\">\n              <ng-template\n                [ngTemplateOutletContext]=\"{\n                  element: element,\n                  column: column,\n                  emiter: column.cellTemplateEmiter\n                }\"\n                [ngTemplateOutlet]=\"column.cellEditTemplate\"\n              >\n              </ng-template>\n            </div>\n            <div *ngSwitchDefault>\n              <input\n                matInput\n                [attr.aria-label]=\"'Input ' + element[column.name]\"\n                placeholder=\"{{ element[column.name] }}\"\n                (click)=\"$event.stopPropagation()\"\n                [(ngModel)]=\"element[column.name]\"\n              />\n            </div>\n          </div>\n        </div>\n      </td>\n      <td\n        mat-footer-cell\n        *matFooterCellDef\n        [ngClass]=\"{\n          left: column.align === 'left',\n          center: column.align === 'center',\n          right: column.align === 'right'\n        }\"\n      >\n        {{ getTotalRowCell(column) }}\n      </td>\n    </ng-container>\n    <ng-container matColumnDef=\"uxg-table-action-row\" *ngIf=\"enableEdit || enableDelete || enableSend\">\n      <th mat-header-cell *matHeaderCellDef class=\"uxg-table-action-column-header\">Actions</th>\n      <td mat-cell *matCellDef=\"let row\" class=\"uxg-table-action-column-cell\">\n        <button\n          *ngIf=\"!row.uxgTableEdit && enableEdit\"\n          mat-icon-button\n          (click)=\"rowEditClick(row); $event.stopPropagation()\"\n        >\n          <mat-icon class=\"material-icons-outlined\">edit_outline</mat-icon>\n        </button>\n        <button\n          *ngIf=\"!row.uxgTableEdit && enableDelete\"\n          mat-icon-button\n          (click)=\"rowDelete(row); $event.stopPropagation()\"\n        >\n          <mat-icon>delete_outline</mat-icon>\n        </button>\n        <button\n          *ngIf=\"!row.uxgTableEdit && enableSend\"\n          mat-icon-button\n          (click)=\"rowSendTriggered(row); $event.stopPropagation()\"\n        >\n          <mat-icon class=\"material-icons-outlined\">send_outline</mat-icon>\n        </button>\n        <button *ngIf=\"row.uxgTableEdit\" mat-icon-button (click)=\"rowEditConfirm(row); $event.stopPropagation()\">\n          <mat-icon>done</mat-icon>\n        </button>\n        <button *ngIf=\"row.uxgTableEdit\" mat-icon-button (click)=\"rowEditCancel(row); $event.stopPropagation()\">\n          <mat-icon class=\"material-icons-outlined\">cancel</mat-icon>\n        </button>\n      </td>\n      <td mat-footer-cell *matFooterCellDef></td>\n    </ng-container>\n\n    <tr\n      mat-header-row\n      *matHeaderRowDef=\"columnsToDisplayToComponent; sticky: stickyHeader\"\n      [ngClass]=\"showTableHeader ? '' : 'uxg-table-no-header'\"\n    ></tr>\n    <tr\n      mat-row\n      *matRowDef=\"let row; columns: columnsToDisplayToComponent\"\n      (click)=\"singleSelectRowClick(row)\"\n      [ngClass]=\"[isRowSelected(row) ? 'selected' : '', row._class ? row._class : '']\"\n    ></tr>\n    <tr\n      mat-footer-row\n      *matFooterRowDef=\"columnsToDisplayToComponent; sticky: stickyFooter\"\n      [ngClass]=\"showTotalRows ? '' : 'hidden-total'\"\n    ></tr>\n  </table>\n</div>\n\n<mat-paginator\n  *ngIf=\"pageEnable\"\n  [disabled]=\"paging?.disabled\"\n  [length]=\"paging?.length\"\n  [hidePageSize]=\"paging?.hidePageSize\"\n  [pageIndex]=\"paging?.pageIndex\"\n  [pageSize]=\"paging?.pageSize\"\n  [pageSizeOptions]=\"paging?.pageSizeOptions\"\n  [showFirstLastButtons]=\"paging?.showFirstLastButtons\"\n  (page)=\"applyPageChanges($event)\"\n>\n</mat-paginator>\n",
                encapsulation: ViewEncapsulation.None,
                styles: ["uxg-table{display:flex;flex:1;overflow:hidden;flex-direction:column;justify-content:space-between;height:100%}uxg-table .uxg-data-table{max-height:none;max-width:inherit;overflow:auto}uxg-table .mat-table{width:100%}uxg-table .mat-table tr td{position:relative;overflow:hidden;box-sizing:border-box}uxg-table .mat-table tr td .uxg-cell-hidden{display:none!important;width:0;height:0}uxg-table .mat-table tr td .uxg-table-row-display{position:absolute}uxg-table .mat-table tr td .uxg-table-row-edit{position:absolute;top:13%;bottom:13%;display:flex!important;align-items:center;overflow:hidden;justify-content:center;height:32px}uxg-table .mat-table tr td .uxg-table-row-edit.uxg-table-row-edit input{width:100%;height:24px}uxg-table .mat-table tr td.uxg-table-action-column-cell{text-align:center}uxg-table .mat-table tr td.left{text-align:left}uxg-table .mat-table tr td.right{text-align:right}uxg-table .mat-table tr td.center{text-align:center}uxg-table .mat-table tr td div{display:flex}uxg-table .mat-table tr td.right div{float:right;display:block}uxg-table .mat-table tr td.left div{float:left;display:block}uxg-table .mat-table tr td.center div{float:center;display:block}uxg-table .mat-table thead tr.uxg-table-no-header{display:none}uxg-table .mat-table thead tr th.uxg-table-action-column-header{text-align:center}uxg-table .mat-table thead tr th.right div{display:flex;flex-direction:row-reverse;place-content:center flex-start;align-items:center}uxg-table .mat-table thead tr th.right div .mat-sort-header-arrow{margin-left:0;margin-right:6px}uxg-table .mat-table thead tr th.left div{display:flex;place-content:center flex-start;align-items:center}uxg-table .mat-table thead tr th.center div{display:flex;place-content:center;align-items:center}uxg-table .mat-table tfoot .hidden-total{display:none}"]
            },] }
];
/** @nocollapse */
TableComponent.ctorParameters = () => [];
TableComponent.propDecorators = {
    table: [{ type: ViewChild, args: [MatTable, { static: true },] }],
    data: [{ type: Input }],
    columnsToDisplay: [{ type: Input }],
    columns: [{ type: Input }],
    showTotalRows: [{ type: Input }],
    showTableHeader: [{ type: Input }],
    totalData: [{ type: Input }],
    stickyHeader: [{ type: Input }],
    stickyFooter: [{ type: Input }],
    columnDragEnable: [{ type: Input }],
    selectedKeys: [{ type: Input }],
    singleSelect: [{ type: Input }],
    multiSelect: [{ type: Input }],
    selectChanged: [{ type: Output }],
    multiSelectSingleRowClicked: [{ type: Output }],
    sortChanged: [{ type: Output }],
    pageEnable: [{ type: Input }],
    paging: [{ type: Input }],
    pageChanged: [{ type: Output }],
    enableEdit: [{ type: Input }],
    enableDelete: [{ type: Input }],
    enableSend: [{ type: Input }],
    actionColumnPosition: [{ type: Input }],
    rowRemoved: [{ type: Output }],
    rowUpdated: [{ type: Output }],
    rowSend: [{ type: Output }]
};

class UxgTableModule {
}
UxgTableModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TableComponent],
                imports: [
                    CommonModule,
                    DragDropModule,
                    MatTableModule,
                    MatPaginatorModule,
                    CdkTableModule,
                    MatSortModule,
                    MatIconModule,
                    MatFormFieldModule,
                    MatProgressSpinnerModule,
                    MatButtonModule,
                    MatCheckboxModule,
                    MatInputModule,
                    FormsModule
                ],
                exports: [TableComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { TableComponent, UxgActionColumnPosition, UxgColumnType, UxgDefaultPaging, UxgTableModule };
//# sourceMappingURL=ffdc-uxg-angular-components-table.js.map
