import { CommonModule } from '@angular/common';
import { Injectable, EventEmitter, Component, Input, Output, Directive, TemplateRef, ContentChild, ViewEncapsulation, ContentChildren, NgModule } from '@angular/core';
import { MatButtonModule } from '@angular/material/button';
import { MatDividerModule } from '@angular/material/divider';
import { MatIconModule } from '@angular/material/icon';
import { Subject } from 'rxjs';
import { MediaObserver, FlexLayoutModule } from '@angular/flex-layout';
import { trigger, transition, query, style, group, animate } from '@angular/animations';

class PageCollectionService {
    constructor() { }
    get pagesAsArray() {
        return this.pages ? this.pages.toArray() : [];
    }
    get pagesCount() {
        return this.pages ? this.pages.length : 0;
    }
    get lastPage() {
        const pageCount = this.pagesCount;
        if (pageCount < 1) {
            return null;
        }
        return this.pagesAsArray[pageCount - 1];
    }
    get firstPage() {
        if (!this.pagesCount) {
            return null;
        }
        return this.pagesAsArray[0];
    }
    getPageById(id) {
        const foundPages = this.pages
            ? this.pages.filter((page) => id === page.id)
            : [];
        return this.checkResults(foundPages, id);
    }
    getPageByIndex(index) {
        const pageCount = this.pagesCount;
        const pagesLastIndex = pageCount > 1 ? pageCount - 1 : 0;
        if (index < 0) {
            throw new Error('Cannot retrieve page with index of ' + index);
        }
        if (index > pagesLastIndex) {
            throw new Error('Page index is greater than length of pages array.');
        }
        return this.pagesAsArray[index];
    }
    getPageIndex(page) {
        if (!page) {
            throw new Error('Requested page cannot be found in collection of pages.');
        }
        const index = this.pagesAsArray.indexOf(page);
        if (index < 0) {
            throw new Error('Requested page cannot be found in collection of pages.');
        }
        return index;
    }
    checkResults(results, requestedPageId) {
        const foundPagesCount = results.length || 0;
        if (foundPagesCount > 1) {
            throw new Error('More than one page has the requested id ' + requestedPageId + '.');
        }
        else if (foundPagesCount < 1) {
            throw new Error('No page can be found with the id ' + requestedPageId + '.');
        }
        else {
            return results[0];
        }
    }
    pageRange(start, end) {
        let pages = [];
        if (start < 0 || end < 0) {
            return [];
        }
        if (start === null || typeof start === 'undefined' || isNaN(start)) {
            return [];
        }
        if (end === null || typeof end === 'undefined' || isNaN(end)) {
            return [];
        }
        if (end > this.pagesCount) {
            end = this.pagesCount;
        }
        pages = this.pagesAsArray;
        if (end - start === 0) {
            return [this.getPageByIndex(start)];
        }
        end = end + 1;
        return pages.slice(start, end);
    }
    getPageRangeFromPages(page, otherPage) {
        const pageIndex = this.getPageIndex(page);
        const otherPageIndex = this.getPageIndex(otherPage);
        let startIndex;
        let endIndex;
        if (pageIndex <= otherPageIndex) {
            startIndex = pageIndex;
            endIndex = otherPageIndex;
        }
        else {
            startIndex = otherPageIndex;
            endIndex = pageIndex;
        }
        return this.pageRange(startIndex, endIndex);
    }
    getPreviousPage(page) {
        const myPageIndex = this.getPageIndex(page);
        let previousPageIndex = myPageIndex - 1;
        let previousPage = null;
        let valid = false;
        while (previousPageIndex >= 0) {
            previousPage = this.getPageByIndex(previousPageIndex);
            if (previousPage.disabled) {
                previousPageIndex--;
            }
            else {
                valid = true;
                break;
            }
        }
        if (!valid) {
            return null;
        }
        return previousPage;
    }
    getNextPage(page) {
        if (!page)
            return null;
        const myPageIndex = this.getPageIndex(page);
        let nextPageIndex = myPageIndex + 1;
        let nextPage = null;
        let valid = false;
        while (nextPageIndex < this.pagesAsArray.length) {
            nextPage = this.getPageByIndex(nextPageIndex);
            if (nextPage.disabled) {
                nextPageIndex++;
            }
            else {
                valid = true;
                break;
            }
        }
        if (!valid) {
            return null;
        }
        return nextPage;
    }
}
PageCollectionService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
PageCollectionService.ctorParameters = () => [];

class ButtonHubService {
    constructor() {
        this.buttonsReady = false;
        this._previousButtonClicked = new Subject();
        this._nextButtonClicked = new Subject();
        this._cancelButtonClicked = new Subject();
        this._doneButtonClicked = new Subject();
        this._customButtonClicked = new Subject();
    }
    get previousButtonClicked() {
        return this._previousButtonClicked.asObservable();
    }
    get nextButtonClicked() {
        return this._nextButtonClicked.asObservable();
    }
    get cancelButtonClicked() {
        return this._cancelButtonClicked.asObservable();
    }
    get doneButtonClicked() {
        return this._doneButtonClicked.asObservable();
    }
    get customButtonClicked() {
        return this._customButtonClicked.asObservable();
    }
    buttonClicked(buttonType) {
        if ('previous' === buttonType) {
            this._previousButtonClicked.next();
        }
        else if ('next' === buttonType) {
            this._nextButtonClicked.next();
        }
        else if ('done' === buttonType) {
            this._doneButtonClicked.next();
        }
        else if ('cancel' === buttonType) {
            this._cancelButtonClicked.next();
        }
        else {
            this._customButtonClicked.next(buttonType);
        }
    }
}
ButtonHubService.decorators = [
    { type: Injectable }
];

class WizardNavigationService {
    constructor(pageCollection, buttonService) {
        this.pageCollection = pageCollection;
        this.buttonService = buttonService;
        this._currentChange = new Subject();
        this._wizardDone = new Subject();
        this._currentPage = null;
        this._wizardCancel = new Subject();
        this._movedToNextPage = new Subject();
        this._movedToPreviousPage = new Subject();
        this.previousButtonSubscription = this.buttonService.previousButtonClicked.subscribe(() => {
            const currentPage = this.currentPage;
            if (!currentPage || this.currentPageIsFirst || currentPage.previousStepDisabled) {
                return;
            }
            currentPage.previousButtonClicked.emit(currentPage);
            this.previous();
        });
        this.nextButtonSubscription = this.buttonService.nextButtonClicked.subscribe(() => {
            this.checkAndCommitCurrentPage('next');
        });
        this.doneButtonSubscription = this.buttonService.doneButtonClicked.subscribe(() => {
            this.checkAndCommitCurrentPage('done');
        });
        this.cancelButtonSubscription = this.buttonService.cancelButtonClicked.subscribe(() => {
            this.cancel();
        });
    }
    get currentPageChange() {
        return this._currentChange.asObservable();
    }
    get currentPageTitle() {
        if (!this.currentPage) {
            return null;
        }
        return this.currentPage.title;
    }
    get currentPageDescription() {
        if (!this.currentPage) {
            return null;
        }
        return this.currentPage.description;
    }
    get currentPageIsFirst() {
        return this.pageCollection.firstPage === this.currentPage;
    }
    get currentPageIsLast() {
        return this.pageCollection.lastPage === this.currentPage;
    }
    get currentPage() {
        return this._currentPage;
    }
    set currentPage(page) {
        if (page && this._currentPage !== page) {
            this._currentPage = page;
            page.load.emit(page.id);
            this._currentChange.next(page);
        }
    }
    setFirstPageCurrent() {
        this.currentPage = this.pageCollection.pagesAsArray[0];
    }
    get wizardDone() {
        return this._wizardDone.asObservable();
    }
    get wizardCancel() {
        return this._wizardCancel.asObservable();
    }
    cancel() {
        this._wizardCancel.next();
    }
    ngOnDestroy() {
        this.nextButtonSubscription.unsubscribe();
        this.previousButtonSubscription.unsubscribe();
        this.doneButtonSubscription.unsubscribe();
        this.cancelButtonSubscription.unsubscribe();
    }
    get movedToNextPage() {
        return this._movedToNextPage.asObservable();
    }
    next() {
        if (this.currentPageIsLast) {
            this.checkAndCommitCurrentPage('done');
        }
        else {
            this.checkAndCommitCurrentPage('next');
        }
    }
    forceNext() {
        const currentPage = this.currentPage;
        const nextPage = this.pageCollection.getNextPage(currentPage);
        if (!nextPage) {
            throw new Error('The wizard has no next page to go to.');
        }
        this.currentPage = nextPage;
    }
    checkAndCommitCurrentPage(buttonType) {
        const currentPage = this.currentPage;
        if (!currentPage)
            return;
        const isNext = buttonType === 'next';
        const isDone = buttonType === 'done';
        if (isDone) {
            currentPage.doneButtonClicked.emit(currentPage);
        }
        else if (isNext) {
            currentPage.nextButtonClicked.emit();
        }
        if (isDone) {
            this._wizardDone.next();
        }
        if (isNext) {
            this.forceNext();
        }
        this._movedToNextPage.next(true);
    }
    get movedToPreviousPage() {
        return this._movedToPreviousPage.asObservable();
    }
    previous() {
        let previousPage;
        if (this.currentPageIsFirst || !this.currentPage) {
            return;
        }
        previousPage = this.pageCollection.getPreviousPage(this.currentPage);
        if (!previousPage) {
            return;
        }
        this._movedToPreviousPage.next(true);
        this.currentPage = previousPage;
    }
    goTo(pageOrId) {
        let pageToGoTo;
        let currentPage;
        let pages;
        let pagesToCheck;
        let currentPageIndex;
        let goToPageIndex;
        let goingForward;
        pages = this.pageCollection;
        pageToGoTo = typeof pageOrId === 'string' ? pages.getPageById(pageOrId) : pageOrId;
        if (!this.currentPage)
            return;
        currentPage = this.currentPage;
        currentPageIndex = pages.getPageIndex(currentPage);
        goToPageIndex = pages.getPageIndex(pageToGoTo);
        goingForward = goToPageIndex > currentPageIndex;
        if (pageToGoTo === currentPage || pageToGoTo.disabled) {
            return;
        }
        pagesToCheck = pages.getPageRangeFromPages(this.currentPage, pageToGoTo);
        if (!pagesToCheck || pagesToCheck.length < 1) {
            return;
        }
        let canGo = true;
        pagesToCheck.forEach((page) => {
            if (goingForward && !page.disabled && page.nextStepDisabled && page !== pageToGoTo) {
                canGo = false;
            }
            else if (!goingForward && !page.disabled && page.previousStepDisabled && page !== pageToGoTo) {
                canGo = false;
            }
        });
        if (!canGo) {
            return;
        }
        this.currentPage = pageToGoTo;
    }
}
WizardNavigationService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
WizardNavigationService.ctorParameters = () => [
    { type: PageCollectionService },
    { type: ButtonHubService }
];

class UxgWizardButtonComponent {
    constructor(navService, buttonService, media) {
        this.navService = navService;
        this.buttonService = buttonService;
        this.media = media;
        this.disabled = false;
        this.hidden = false;
        this.alwaysShow = false;
        this.wasClicked = new EventEmitter(false);
    }
    checkDefaultType(value, type) {
        return value === type;
    }
    get isNext() {
        return this.checkDefaultType(this.type, 'next');
    }
    get isPrevious() {
        return this.checkDefaultType(this.type, 'previous');
    }
    get isDone() {
        return this.checkDefaultType(this.type, 'done');
    }
    get isCancel() {
        return this.checkDefaultType(this.type, 'cancel');
    }
    get isCustom() {
        return this.checkDefaultType(this.type, 'custom');
    }
    get isDisabled() {
        const disabled = true;
        const nav = this.navService;
        const page = this.navService.currentPage;
        if (!this.buttonService.buttonsReady) {
            return !disabled;
        }
        if (this.disabled || !page) {
            return true;
        }
        if (this.isCancel) {
            return !disabled;
        }
        if (this.isPrevious && (nav.currentPageIsFirst || page.previousStepDisabled)) {
            return disabled;
        }
        if (this.isNext && (nav.currentPageIsLast || page.nextStepDisabled)) {
            return disabled;
        }
        return !disabled;
    }
    get isHidden() {
        const hidden = true;
        const nav = this.navService;
        if (!this.buttonService.buttonsReady) {
            return !hidden;
        }
        if (this.hidden) {
            return true;
        }
        if (this.isCancel) {
            return !hidden;
        }
        if (this.isPrevious && nav.currentPageIsFirst) {
            return hidden;
        }
        if (this.isNext && nav.currentPageIsLast) {
            return hidden;
        }
        if (this.isDone && !nav.currentPageIsLast && !this.alwaysShow) {
            return hidden;
        }
        return !hidden;
    }
    get disabledAttribute() {
        if (this.isDisabled) {
            return '';
        }
        return null;
    }
    click() {
        if (this.isDisabled) {
            return;
        }
        this.wasClicked.emit(this.type);
        this.buttonService.buttonClicked(this.type);
    }
}
UxgWizardButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-wizard-button',
                template: "<ng-container [ngSwitch]=\"type\">\n  <button\n    *ngSwitchDefault\n    mat-button\n    color=\"accent\"\n    [attr.large]=\"!media.isActive('xs') || null\"\n    [attr.dense]=\"media.isActive('xs') || null\"\n    [disabled]=\"disabledAttribute\"\n    [class.disabled]=\"isDisabled\"\n    (click)=\"click()\"\n  >\n    <ng-container *ngTemplateOutlet=\"contentTpl\"></ng-container>\n  </button>\n  <button\n    *ngSwitchCase=\"'next'\"\n    mat-stroked-button\n    color=\"accent\"\n    [attr.large]=\"!media.isActive('xs') || null\"\n    [attr.dense]=\"media.isActive('xs') || null\"\n    [disabled]=\"disabledAttribute\"\n    [class.disabled]=\"isDisabled\"\n    (click)=\"click()\"\n  >\n    <ng-container *ngTemplateOutlet=\"contentTpl\"></ng-container>\n  </button>\n  <button\n    *ngSwitchCase=\"'done'\"\n    mat-flat-button\n    color=\"accent\"\n    [attr.large]=\"!media.isActive('xs') || null\"\n    [attr.dense]=\"media.isActive('xs') || null\"\n    [disabled]=\"disabledAttribute\"\n    [class.disabled]=\"isDisabled\"\n    (click)=\"click()\"\n  >\n    <ng-container *ngTemplateOutlet=\"contentTpl\"></ng-container>\n  </button>\n  <div *ngSwitchCase=\"'custom'\">\n    <ng-container *ngTemplateOutlet=\"contentTpl\"></ng-container>\n  </div>\n</ng-container>\n\n<ng-template #contentTpl><ng-content></ng-content></ng-template>\n",
                host: {
                    '[class.uxg-wizard-button]': 'true',
                    '[class.auto-margin]': 'isCancel || isCustom',
                    '[attr.aria-hidden]': 'isHidden',
                    '[attr.type]': 'type'
                }
            },] }
];
/** @nocollapse */
UxgWizardButtonComponent.ctorParameters = () => [
    { type: WizardNavigationService },
    { type: ButtonHubService },
    { type: MediaObserver }
];
UxgWizardButtonComponent.propDecorators = {
    type: [{ type: Input }],
    disabled: [{ type: Input, args: ['uxgWizardButtonDisabled',] }],
    hidden: [{ type: Input, args: ['uxgWizardButtonHidden',] }],
    alwaysShow: [{ type: Input, args: ['uxgWizardButtonAlwaysShow',] }],
    wasClicked: [{ type: Output, args: ['uxgWizardButtonClicked',] }]
};

class UxgWizardPageDescriptionComponent {
    constructor(pageDescriptionTemplateRef) {
        this.pageDescriptionTemplateRef = pageDescriptionTemplateRef;
    }
}
UxgWizardPageDescriptionComponent.decorators = [
    { type: Directive, args: [{ selector: '[uxgWizardPageDescription]' },] }
];
/** @nocollapse */
UxgWizardPageDescriptionComponent.ctorParameters = () => [
    { type: TemplateRef }
];

class UxgWizardPageTitleComponent {
    constructor(pageTitleTemplateRef) {
        this.pageTitleTemplateRef = pageTitleTemplateRef;
    }
}
UxgWizardPageTitleComponent.decorators = [
    { type: Directive, args: [{ selector: '[uxgWizardPageTitle]' },] }
];
/** @nocollapse */
UxgWizardPageTitleComponent.ctorParameters = () => [
    { type: TemplateRef }
];

class UxgWizardPageComponent {
    constructor(navService, pageCollection, buttonService) {
        this.navService = navService;
        this.pageCollection = pageCollection;
        this.buttonService = buttonService;
        this.load = new EventEmitter();
        this.nextButtonClicked = new EventEmitter();
        this.previousButtonClicked = new EventEmitter();
        this.doneButtonClicked = new EventEmitter();
        this._disabled = false;
        this.pageDisabledChange = new EventEmitter();
        this._nextStepDisabled = false;
        this.nextStepDisabledChange = new EventEmitter();
        this._previousStepDisabled = false;
        this.previousStepDisabledChange = new EventEmitter();
        this._showTitle = true;
    }
    get id() {
        return `uxg-wizard-page-${this.pageCollection.getPageIndex(this)}`;
    }
    get current() {
        return this.navService.currentPage === this;
    }
    get disabled() {
        return this._disabled;
    }
    set disabled(val) {
        if (val !== this._disabled) {
            this._disabled = val;
            this.pageDisabledChange.emit(val);
        }
    }
    get nextStepDisabled() {
        return this._nextStepDisabled;
    }
    set nextStepDisabled(val) {
        if (val !== this._nextStepDisabled) {
            this._nextStepDisabled = val;
            this.nextStepDisabledChange.emit(val);
        }
    }
    get previousStepDisabled() {
        return this._previousStepDisabled;
    }
    set previousStepDisabled(val) {
        if (val !== this._previousStepDisabled) {
            this._previousStepDisabled = val;
            this.previousStepDisabledChange.emit(val);
        }
    }
    get title() {
        return this.pageTitle.pageTitleTemplateRef;
    }
    get description() {
        return this.pageDescription.pageDescriptionTemplateRef;
    }
    get showTitle() {
        return this._showTitle;
    }
    set showTitle(val) {
        this._showTitle = val;
    }
}
UxgWizardPageComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-wizard-page',
                template: '<ng-content *ngIf="current"></ng-content>',
                host: {
                    '[id]': 'id',
                    role: 'tabpanel',
                    '[attr.aria-hidden]': '!current',
                    '[class.active]': 'current',
                    '[class.no-title]': '!showTitle',
                    '[class.uxg-wizard-page]': 'true'
                }
            },] }
];
/** @nocollapse */
UxgWizardPageComponent.ctorParameters = () => [
    { type: WizardNavigationService },
    { type: PageCollectionService },
    { type: ButtonHubService }
];
UxgWizardPageComponent.propDecorators = {
    load: [{ type: Output, args: ['uxgWizardPageOnLoad',] }],
    nextButtonClicked: [{ type: Output, args: ['uxgWizardPageNext',] }],
    previousButtonClicked: [{ type: Output, args: ['uxgWizardPagePrevious',] }],
    doneButtonClicked: [{ type: Output, args: ['uxgWizardPageDone',] }],
    pageTitle: [{ type: ContentChild, args: [UxgWizardPageTitleComponent, { static: true },] }],
    pageDescription: [{ type: ContentChild, args: [UxgWizardPageDescriptionComponent, { static: true },] }],
    disabled: [{ type: Input, args: ['uxgWizardPageDisabled',] }],
    pageDisabledChange: [{ type: Output, args: ['uxgWizardPageDisabledChange',] }],
    nextStepDisabled: [{ type: Input, args: ['uxgWizardPageNextDisabled',] }],
    nextStepDisabledChange: [{ type: Output, args: ['uxgWizardPageNextDisabledChange',] }],
    previousStepDisabled: [{ type: Input, args: ['uxgWizardPagePreviousDisabled',] }],
    previousStepDisabledChange: [{ type: Output, args: ['uxgWizardPagePreviousDisabledChange',] }]
};

function wizardAnimation() {
    return trigger('wizardAnimation', [
        // Previous, slide left to right to show left page
        transition(':decrement', [
            // set new page X location to be -100%
            query(':enter', style({
                width: '100%',
                transform: 'translateX(-100%)'
            })),
            group([
                // slide existing page from 0% to 100% to the right
                query(':leave', animate('500ms ease-in-out', style({
                    opacity: 0,
                    width: '100%',
                    transform: 'translateX(100%)'
                }))),
                // slide new page from -100% to 0% to the right
                query(':enter', animate('500ms ease-in-out', style({
                    opacity: 1,
                    transform: 'translateX(0%)'
                })))
            ])
        ]),
        // Next, slide right to left to show right page
        transition(':increment', [
            // set new page X location to be 100%
            query(':enter', style({
                width: '100%',
                transform: 'translateX(100%)'
            })),
            group([
                // slide existing page from 0% to -100% to the left
                query(':leave', animate('500ms ease-in-out', style({
                    opacity: 0,
                    width: '100%',
                    transform: 'translateX(-100%)'
                }))),
                // slide new page from 100% to 0% to the left
                query(':enter', animate('500ms ease-in-out', style({
                    opacity: 1,
                    transform: 'translateX(0%)'
                })))
            ])
        ])
    ]);
}

class UxgWizardComponent {
    constructor(navService, pageCollection, buttonService) {
        this.navService = navService;
        this.pageCollection = pageCollection;
        this.buttonService = buttonService;
        this.showPageTitles = true;
        this.showCloseButton = true;
        this.startingPage = 0;
        this.cancel = new EventEmitter(false);
        this.done = new EventEmitter(false);
        this.currentPageChange = new EventEmitter(false);
        this.currentPageId = -1;
        this.subscriptions = [];
        this.swipeCoord = [0, 0];
        this.swipeTime = 0;
        this.subscriptions.push(this.listenForCancelChanges(), this.listenForDoneChanges(), this.listenForPageChanges());
    }
    get currentPage() {
        return this.navService.currentPage;
    }
    set currentPage(page) {
        if (page)
            this.navService.goTo(page);
    }
    get isLast() {
        return this.navService.currentPageIsLast;
    }
    get isFirst() {
        return this.navService.currentPageIsFirst;
    }
    ngAfterContentInit() {
        this.pages.forEach((page) => (page.showTitle = this.showPageTitles));
        this.pageCollection.pages = this.pages;
        if (!this.currentPage) {
            if (this.startingPage) {
                this.navService.currentPage = this.pageCollection.pagesAsArray[this.startingPage];
            }
            else {
                this.navService.setFirstPageCurrent();
            }
        }
        this.buttonService.buttonsReady = true;
    }
    ngOnDestroy() {
        this.subscriptions.forEach((s) => s.unsubscribe());
    }
    onStepClick(page) {
        this.currentPage = page;
    }
    swipe(e, when) {
        const coord = [e.changedTouches[0].clientX, e.changedTouches[0].clientY];
        const time = new Date().getTime();
        if (when === 'start') {
            this.swipeCoord = coord;
            this.swipeTime = time;
        }
        else {
            const direction = [coord[0] - this.swipeCoord[0], coord[1] - this.swipeCoord[1]];
            const duration = time - this.swipeTime;
            if (duration < 1000 && Math.abs(direction[0]) > 30 && Math.abs(direction[0]) > Math.abs(direction[1] * 3)) {
                const swipe = direction[0] < 0 ? 'next' : 'previous';
                if (swipe === 'next') {
                    this.navService.next();
                }
                else {
                    this.navService.previous();
                }
            }
        }
    }
    listenForCancelChanges() {
        return this.navService.wizardCancel.subscribe(() => this.cancel.emit());
    }
    listenForDoneChanges() {
        return this.navService.wizardDone.subscribe(() => this.done.emit());
    }
    listenForPageChanges() {
        return this.navService.currentPageChange.subscribe((page) => {
            this.currentPageId = this.pageCollection.getPageIndex(page);
            this.currentPageChange.emit();
        });
    }
}
UxgWizardComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-wizard',
                providers: [WizardNavigationService, PageCollectionService, ButtonHubService],
                template: "<div fxFlexFill fxLayout=\"row\" fxLayout.xs=\"column\" class=\"uxg-wizard\">\n  <div fxFlex=\"66\" fxFlex.xs=\"0\"></div>\n  <div fxHide.xs fxFlex class=\"uxg-wizard-right-panel\">\n    <div *ngIf=\"showCloseButton\" class=\"close-button\">\n      <button mat-icon-button (click)=\"navService.cancel()\">\n        <mat-icon aria-hidden=\"false\" aria-label=\"Close\">clear</mat-icon>\n      </button>\n    </div>\n  </div>\n  <h4 fxHide.xs class=\"uxg-wizard-title uxg-h4\">\n    <ng-content select=\"uxg-wizard-title\"></ng-content>\n  </h4>\n\n  <div fxHide fxShow.xs fxLayout=\"column\" class=\"uxg-wizard-timeline-xs\">\n    <div fxLayout=\"row\" fxLayoutAlign=\"space-around\">\n      <div class=\"step active\">\n        <div>{{ navService.currentPage ? pageCollection.getPageIndex(navService.currentPage) + 1 : 1 }}</div>\n      </div>\n      <div fxFlex=\"80\" fxLayout=\"column\" fxLayoutAlign=\"space-around stretch\">\n        <div class=\"step-info-container\">\n          <div class=\"step-title uxg-h5\">\n            <ng-template [ngTemplateOutlet]=\"navService.currentPageTitle\"></ng-template>\n          </div>\n          <div class=\"step-description\">\n            <ng-template [ngTemplateOutlet]=\"navService.currentPageDescription\"></ng-template>\n          </div>\n        </div>\n      </div>\n      <div *ngIf=\"showCloseButton\" class=\"close-button\">\n        <button mat-icon-button (click)=\"navService.cancel()\">\n          <mat-icon aria-hidden=\"false\" aria-label=\"Close\">clear</mat-icon>\n        </button>\n      </div>\n    </div>\n  </div>\n\n  <div\n    class=\"uxg-wizard-container mat-elevation-z4\"\n    fxLayout=\"column\"\n    fxFlex.xs=\"100\"\n    [ngClass.xs]=\"'xs'\"\n    (touchstart)=\"swipe($event, 'start')\"\n    (touchend)=\"swipe($event, 'end')\"\n  >\n    <main [@wizardAnimation]=\"currentPageId\" class=\"uxg-wizard-content\" fxFlex>\n      <div fxHide.xs *ngIf=\"showPageTitles\" class=\"uxg-wizard-page-title uxg-h3\">\n        <ng-template [ngTemplateOutlet]=\"navService.currentPageTitle\"></ng-template>\n      </div>\n      <ng-content></ng-content>\n    </main>\n\n    <mat-divider></mat-divider>\n    <div class=\"uxg-wizard-footer\" fxFlex=\"10\" [ngClass.xs]=\"'xs'\">\n      <div class=\"uxg-wizard-footer-buttons-wrapper\">\n        <ng-content select=\"uxg-wizard-button\"></ng-content>\n\n        <div fxHide fxShow.xs class=\"dot-navigation\">\n          <div fxFlex=\"70\" fxLayout=\"row\" fxLayoutAlign=\"center\" class=\"dot-navigation-flex\">\n            <ng-container *ngFor=\"let page of pages\">\n              <div\n                class=\"dot\"\n                [ngClass]=\"{\n                  active: page.current\n                }\"\n                (click)=\"onStepClick(page)\"\n              ></div>\n            </ng-container>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div fxHide.xs fxLayout=\"row\" class=\"uxg-wizard-timeline\">\n    <div fxFlex=\"20\" fxLayout=\"column\" fxLayoutAlign=\"space-around center\">\n      <div class=\"timeline-progress-bar\" [ngStyle]=\"{ 'height.%': (100 * (pages.length - 1)) / pages.length }\">\n        <span\n          id=\"dp-create-project-wizard-timeline-progress\"\n          class=\"timeline-progress\"\n          [ngStyle]=\"{ 'height.%': (100 * currentPageId) / (pages.length - 1) }\"\n        ></span>\n      </div>\n      <ng-container *ngFor=\"let page of pages\">\n        <div\n          class=\"step\"\n          [ngClass]=\"{\n            done: pageCollection.getPageIndex(page) < currentPageId,\n            active: page.current,\n            disabled: page.disabled\n          }\"\n          (click)=\"onStepClick(page)\"\n        >\n          <ng-container *ngIf=\"pageCollection.getPageIndex(page) < currentPageId; else showIndex\">\n            <mat-icon>checkmark</mat-icon>\n          </ng-container>\n          <ng-template #showIndex>\n            <div>{{ pageCollection.getPageIndex(page) + 1 }}</div>\n          </ng-template>\n        </div>\n      </ng-container>\n    </div>\n    <div fxFlex=\"80\" fxLayout=\"column\" fxLayoutAlign=\"space-around stretch\">\n      <ng-container *ngFor=\"let page of pages\">\n        <div\n          fxLayout=\"column\"\n          class=\"step-info-container\"\n          [ngClass]=\"{\n            active: page.current,\n            disabled: page.disabled\n          }\"\n          (click)=\"onStepClick(page)\"\n        >\n          <div class=\"step-title uxg-h5\">\n            <ng-template [ngTemplateOutlet]=\"page.title\"></ng-template>\n          </div>\n          <div class=\"step-description\">\n            <ng-template [ngTemplateOutlet]=\"page.description\"></ng-template>\n          </div>\n        </div>\n      </ng-container>\n    </div>\n  </div>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                host: {
                    '[class.uxg-wizard]': 'true'
                },
                animations: [wizardAnimation()],
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}.uxg-wizard{position:relative}.uxg-wizard .uxg-wizard-container{position:absolute;border-radius:6px;top:8%;bottom:5%;left:5%;right:22%}.uxg-wizard .uxg-wizard-container.xs{position:static;width:100%}.uxg-wizard .uxg-wizard-container.xs uxg-wizard-page{width:100%;top:0}.uxg-wizard .uxg-wizard-content{position:relative}.uxg-wizard .uxg-wizard-right-panel .close-button{float:right;padding:16px}.uxg-wizard .uxg-wizard-title{position:absolute;display:flex;justify-content:center;top:3%;left:5%;right:22%}.uxg-wizard .uxg-wizard-footer{display:flex;align-items:center;margin:0 16px}.uxg-wizard .uxg-wizard-footer .dot-navigation{order:2;margin-left:auto;width:50%}.uxg-wizard .uxg-wizard-footer .dot-navigation .dot-navigation-flex{margin:auto}.uxg-wizard .uxg-wizard-footer .dot-navigation .dot-navigation-flex .dot{width:8px;height:8px;border-radius:50%;margin:4px}.uxg-wizard .uxg-wizard-footer.xs{margin-left:0}.uxg-wizard .uxg-wizard-footer.xs uxg-wizard-button{align-self:center}.uxg-wizard .uxg-wizard-footer.xs uxg-wizard-button[type=cancel]{display:none}.uxg-wizard .uxg-wizard-footer.xs uxg-wizard-button[type=previous]{margin-right:0;margin-left:0}.uxg-wizard .uxg-wizard-footer.xs uxg-wizard-button[type=previous][aria-hidden=true]{display:initial;visibility:hidden}.uxg-wizard .uxg-wizard-footer.xs uxg-wizard-button[type=done],.uxg-wizard .uxg-wizard-footer.xs uxg-wizard-button[type=next]{order:3;margin-right:0;margin-left:auto}.uxg-wizard .uxg-wizard-footer-buttons-wrapper{display:flex;width:100%;min-height:44px;height:44px}.uxg-wizard .uxg-wizard-page-title{display:flex;align-items:center;justify-content:center;height:12%}.uxg-wizard .uxg-wizard-timeline{position:absolute;top:15%;right:2%;bottom:15%;width:calc(22% + 4px)}.uxg-wizard .uxg-wizard-timeline .step{width:42px;height:42px;border:4px solid;border-radius:50%;display:flex;align-items:center;justify-content:center;cursor:pointer;overflow:hidden;box-sizing:border-box;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;margin-left:4px;z-index:2}.uxg-wizard .uxg-wizard-timeline .step.done{-webkit-animation:pop .5s;animation:pop .5s}.uxg-wizard .uxg-wizard-timeline .step.disabled{pointer-events:none}.uxg-wizard .uxg-wizard-timeline .timeline-progress-bar{position:absolute;width:4px;margin-left:2px;z-index:1}.uxg-wizard .uxg-wizard-timeline .timeline-progress-bar .timeline-progress{position:absolute;width:4px;transition:.5s}.uxg-wizard .uxg-wizard-timeline .step-info-container{cursor:pointer;height:115px;justify-content:center;padding:16px}.uxg-wizard .uxg-wizard-timeline .step-info-container .step-title{transition:color .25s ease-in;margin-bottom:8px}.uxg-wizard .uxg-wizard-timeline .step-info-container .step-description{transition:color .25s ease-in}.uxg-wizard .uxg-wizard-timeline .step-info-container.disabled{pointer-events:none}.uxg-wizard .uxg-wizard-timeline .step-info-container.active{border-radius:4px}.uxg-wizard .uxg-wizard-timeline-xs{width:100%;padding:16px}.uxg-wizard .uxg-wizard-timeline-xs .step{width:36px;height:36px;margin-right:8px;border:4px solid;border-radius:50%;display:flex;align-items:center;justify-content:center;cursor:pointer;overflow:hidden;box-sizing:border-box;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.uxg-wizard .uxg-wizard-timeline-xs .step.active{align-self:center}.uxg-wizard .uxg-wizard-timeline-xs .step-title{margin-bottom:8px}.uxg-wizard .uxg-wizard-timeline-xs .close-button{position:absolute;right:.5em;top:0}uxg-wizard-button{margin-right:2rem;margin-left:1rem}uxg-wizard-button[aria-hidden=true]{display:none}uxg-wizard-button.auto-margin{margin-right:auto}uxg-wizard-page{overflow-y:auto;overflow-x:hidden;display:flex;flex-direction:column;position:absolute;bottom:0;top:12%;right:2rem;left:0}uxg-wizard-page[aria-hidden=true]{z-index:0}uxg-wizard-page.active{z-index:1}uxg-wizard-page.no-title{top:0}@-webkit-keyframes pop{50%{transform:scale(1.5)}to{transform:scale(1)}}@keyframes pop{50%{transform:scale(1.5)}to{transform:scale(1)}}"]
            },] }
];
/** @nocollapse */
UxgWizardComponent.ctorParameters = () => [
    { type: WizardNavigationService },
    { type: PageCollectionService },
    { type: ButtonHubService }
];
UxgWizardComponent.propDecorators = {
    pages: [{ type: ContentChildren, args: [UxgWizardPageComponent,] }],
    showPageTitles: [{ type: Input, args: ['uxgWizardShowPageTitles',] }],
    showCloseButton: [{ type: Input, args: ['uxgWizardShowCloseButton',] }],
    startingPage: [{ type: Input, args: ['uxgWizardStartingPage',] }],
    cancel: [{ type: Output, args: ['uxgWizardOnCancel',] }],
    done: [{ type: Output, args: ['uxgWizardOnDone',] }],
    currentPageChange: [{ type: Output, args: ['uxgWizardCurrentPageChange',] }]
};

class UxgWizardTitleComponent {
}
UxgWizardTitleComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-wizard-title',
                template: ` <ng-content></ng-content> `
            },] }
];

class WizardModule {
}
WizardModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FlexLayoutModule, MatIconModule, MatButtonModule, MatDividerModule],
                declarations: [
                    UxgWizardComponent,
                    UxgWizardTitleComponent,
                    UxgWizardPageComponent,
                    UxgWizardPageTitleComponent,
                    UxgWizardPageDescriptionComponent,
                    UxgWizardButtonComponent
                ],
                exports: [
                    UxgWizardComponent,
                    UxgWizardTitleComponent,
                    UxgWizardPageComponent,
                    UxgWizardPageTitleComponent,
                    UxgWizardPageDescriptionComponent,
                    UxgWizardButtonComponent
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { UxgWizardButtonComponent, UxgWizardComponent, UxgWizardPageComponent, UxgWizardPageDescriptionComponent, UxgWizardPageTitleComponent, UxgWizardTitleComponent, WizardModule, WizardNavigationService as ɵa, PageCollectionService as ɵb, ButtonHubService as ɵc, wizardAnimation as ɵd };
//# sourceMappingURL=ffdc-uxg-angular-components-wizard.js.map
